/* Generated automatically by the program `gencodes'
   from the machine description file `md'.  */

#ifndef GCC_INSN_CODES_H
#define GCC_INSN_CODES_H

enum insn_code {
  CODE_FOR_nothing = 0,
   CODE_FOR_adddi3_high = CODE_FOR_nothing,
   CODE_FOR_movdf_low_si = CODE_FOR_nothing,
   CODE_FOR_movdf_low_di = CODE_FOR_nothing,
   CODE_FOR_movdf_low_st_si = CODE_FOR_nothing,
   CODE_FOR_movdf_low_st_di = CODE_FOR_nothing,
   CODE_FOR_movsf_low_si = CODE_FOR_nothing,
   CODE_FOR_movsf_low_di = CODE_FOR_nothing,
   CODE_FOR_movsf_low_st_si = CODE_FOR_nothing,
   CODE_FOR_movsf_low_st_di = CODE_FOR_nothing,
   CODE_FOR_macho_high_si = CODE_FOR_nothing,
   CODE_FOR_macho_high_di = CODE_FOR_nothing,
   CODE_FOR_macho_low_si = CODE_FOR_nothing,
   CODE_FOR_macho_low_di = CODE_FOR_nothing,
   CODE_FOR_machopic_high_si = CODE_FOR_nothing,
   CODE_FOR_machopic_high_di = CODE_FOR_nothing,
   CODE_FOR_machopic_low_si = CODE_FOR_nothing,
   CODE_FOR_machopic_low_di = CODE_FOR_nothing,
  CODE_FOR_macho_correct_pic_si = 1,
  CODE_FOR_macho_correct_pic_di = 2,
  CODE_FOR_load_macho_picbase_si = 3,
  CODE_FOR_load_macho_picbase_di = 4,
  CODE_FOR_reload_macho_picbase_si = 5,
  CODE_FOR_reload_macho_picbase_di = 6,
   CODE_FOR_nonlocal_goto_receiver = CODE_FOR_nothing,
  CODE_FOR_zero_extendqisi2 = 7,
  CODE_FOR_zero_extendqidi2 = 8,
  CODE_FOR_zero_extendhisi2 = 13,
  CODE_FOR_zero_extendhidi2 = 14,
  CODE_FOR_zero_extendsidi2 = 19,
  CODE_FOR_extendqisi2 = 22,
  CODE_FOR_extendqidi2 = 23,
  CODE_FOR_extendsidi2 = 34,
  CODE_FOR_dlmzb = 67,
  CODE_FOR_addsi3_carry = 78,
  CODE_FOR_adddi3_carry = 79,
  CODE_FOR_addsi3_carry_in_0 = 92,
  CODE_FOR_adddi3_carry_in_0 = 93,
  CODE_FOR_addsi3_carry_in_m1 = 94,
  CODE_FOR_adddi3_carry_in_m1 = 95,
  CODE_FOR_subfsi3_imm = 108,
  CODE_FOR_subfdi3_imm = 109,
  CODE_FOR_subfsi3_carry_dot2 = 110,
  CODE_FOR_subfdi3_carry_dot2 = 111,
  CODE_FOR_subfsi3_carry = 112,
  CODE_FOR_subfdi3_carry = 113,
  CODE_FOR_subfsi3_carry_in_0 = 120,
  CODE_FOR_subfdi3_carry_in_0 = 121,
  CODE_FOR_subfsi3_carry_in_m1 = 122,
  CODE_FOR_subfdi3_carry_in_m1 = 123,
  CODE_FOR_subfsi3_carry_in_xx = 124,
  CODE_FOR_subfdi3_carry_in_xx = 125,
  CODE_FOR_negsi2 = 127,
  CODE_FOR_negdi2 = 128,
  CODE_FOR_clzsi2 = 133,
  CODE_FOR_clzdi2 = 134,
  CODE_FOR_ctzsi2_hw = 135,
  CODE_FOR_ctzdi2_hw = 136,
  CODE_FOR_popcntbsi2 = 137,
  CODE_FOR_popcntbdi2 = 138,
  CODE_FOR_popcntdsi2 = 139,
  CODE_FOR_popcntddi2 = 140,
  CODE_FOR_paritysi2_cmpb = 141,
  CODE_FOR_paritydi2_cmpb = 142,
  CODE_FOR_cfuged = 143,
  CODE_FOR_cntlzdm = 144,
  CODE_FOR_cnttzdm = 145,
  CODE_FOR_pdepd = 146,
  CODE_FOR_pextd = 147,
  CODE_FOR_cmpbsi3 = 148,
  CODE_FOR_cmpbdi3 = 149,
  CODE_FOR_bswaphi2_load = 153,
  CODE_FOR_bswapsi2_load = 154,
  CODE_FOR_bswaphi2_store = 155,
  CODE_FOR_bswapsi2_store = 156,
  CODE_FOR_bswaphi2_reg = 157,
  CODE_FOR_bswapsi2_reg = 158,
  CODE_FOR_bswapdi2_load = 159,
  CODE_FOR_bswapdi2_store = 160,
  CODE_FOR_bswapdi2_brd = 161,
  CODE_FOR_bswapdi2_reg = 162,
  CODE_FOR_bswapdi2_32bit = 164,
  CODE_FOR_mulsi3 = 165,
  CODE_FOR_muldi3 = 166,
  CODE_FOR_smulsi3_highpart_le = 175,
  CODE_FOR_umulsi3_highpart_le = 176,
  CODE_FOR_smuldi3_highpart_le = 177,
  CODE_FOR_umuldi3_highpart_le = 178,
  CODE_FOR_smulsi3_highpart_64 = 179,
  CODE_FOR_umulsi3_highpart_64 = 180,
  CODE_FOR_maddldsi4 = 181,
  CODE_FOR_maddlddi4 = 182,
  CODE_FOR_madddi4_highpart = 183,
  CODE_FOR_umadddi4_highpart = 184,
  CODE_FOR_madddi4_highpart_le = 185,
  CODE_FOR_umadddi4_highpart_le = 186,
  CODE_FOR_udivsi3 = 187,
  CODE_FOR_udivdi3 = 188,
  CODE_FOR_udivti3 = 189,
  CODE_FOR_divsi3_sra = 192,
  CODE_FOR_divdi3_sra = 193,
  CODE_FOR_divti3 = 198,
   CODE_FOR_umodti3 = CODE_FOR_nothing,
   CODE_FOR_modti3 = CODE_FOR_nothing,
  CODE_FOR_andsi3_imm = 199,
  CODE_FOR_anddi3_imm = 200,
  CODE_FOR_andsi3_mask = 211,
  CODE_FOR_anddi3_mask = 212,
  CODE_FOR_rotlsi3_insert_3 = 260,
  CODE_FOR_rotldi3_insert_3 = 261,
  CODE_FOR_rotlsi3 = 275,
  CODE_FOR_rotldi3 = 276,
  CODE_FOR_ashlsi3 = 282,
  CODE_FOR_ashldi3 = 283,
  CODE_FOR_ashdi3_extswsli = 289,
  CODE_FOR_ashdi3_extswsli_dot = 290,
  CODE_FOR_ashdi3_extswsli_dot2 = 291,
  CODE_FOR_lshrsi3 = 292,
  CODE_FOR_lshrdi3 = 293,
  CODE_FOR_ashrsi3 = 299,
  CODE_FOR_ashrdi3 = 300,
  CODE_FOR_fres = 322,
  CODE_FOR_fred = 323,
  CODE_FOR_signbitkf2_dm = 331,
  CODE_FOR_signbittf2_dm = 332,
  CODE_FOR_signbitkf2_dm_mem = 333,
  CODE_FOR_signbittf2_dm_mem = 334,
  CODE_FOR_copysignsf3_fcpsgn = 335,
  CODE_FOR_copysigndf3_fcpsgn = 336,
  CODE_FOR_sminkf3 = 341,
  CODE_FOR_smaxkf3 = 342,
  CODE_FOR_smintf3 = 343,
  CODE_FOR_smaxtf3 = 344,
  CODE_FOR_fmaxsf3 = 349,
  CODE_FOR_fminsf3 = 350,
  CODE_FOR_fmaxdf3 = 351,
  CODE_FOR_fmindf3 = 352,
  CODE_FOR_isel_cc_si = 353,
  CODE_FOR_isel_cc_di = 354,
  CODE_FOR_isel_ccuns_si = 355,
  CODE_FOR_isel_ccuns_di = 356,
  CODE_FOR_setbc_cc_si = 361,
  CODE_FOR_setbc_cc_di = 362,
  CODE_FOR_setbc_ccuns_si = 363,
  CODE_FOR_setbc_ccuns_di = 364,
  CODE_FOR_lfiwax = 401,
  CODE_FOR_floatsisf2_lfiwax = 402,
  CODE_FOR_floatsidf2_lfiwax = 403,
  CODE_FOR_floatsisf2_lfiwax_mem = 404,
  CODE_FOR_floatsidf2_lfiwax_mem = 405,
  CODE_FOR_floatsisf2_lfiwax_qi_mem_zext = 406,
  CODE_FOR_floatsisf2_lfiwax_hi_mem_zext = 407,
  CODE_FOR_floatsidf2_lfiwax_qi_mem_zext = 408,
  CODE_FOR_floatsidf2_lfiwax_hi_mem_zext = 409,
  CODE_FOR_lfiwzx = 410,
  CODE_FOR_floatunssisf2_lfiwzx = 411,
  CODE_FOR_floatunssidf2_lfiwzx = 412,
  CODE_FOR_floatunssisf2_lfiwzx_mem = 413,
  CODE_FOR_floatunssidf2_lfiwzx_mem = 414,
  CODE_FOR_fix_truncsfsi2_stfiwx = 425,
  CODE_FOR_fix_truncdfsi2_stfiwx = 426,
  CODE_FOR_fix_truncsfsi2_internal = 427,
  CODE_FOR_fix_truncdfsi2_internal = 428,
  CODE_FOR_fix_truncsfqi2 = 431,
  CODE_FOR_fixuns_truncsfqi2 = 432,
  CODE_FOR_fix_truncsfhi2 = 433,
  CODE_FOR_fixuns_truncsfhi2 = 434,
  CODE_FOR_fix_truncdfqi2 = 435,
  CODE_FOR_fixuns_truncdfqi2 = 436,
  CODE_FOR_fix_truncdfhi2 = 437,
  CODE_FOR_fixuns_truncdfhi2 = 438,
  CODE_FOR_fixuns_truncsfsi2_stfiwx = 455,
  CODE_FOR_fixuns_truncdfsi2_stfiwx = 456,
  CODE_FOR_fixuns_truncsfdi2 = 457,
  CODE_FOR_fixuns_truncdfdi2 = 458,
  CODE_FOR_rs6000_mtfsb0 = 459,
  CODE_FOR_rs6000_mtfsb1 = 460,
  CODE_FOR_rs6000_mffscrn = 461,
  CODE_FOR_rs6000_mffscrni = 462,
  CODE_FOR_rs6000_mffscdrn = 463,
  CODE_FOR_fctiwz_sf = 464,
  CODE_FOR_fctiwz_df = 465,
  CODE_FOR_fctiwuz_sf = 466,
  CODE_FOR_fctiwuz_df = 467,
  CODE_FOR_lrintsfdi2 = 473,
  CODE_FOR_lrintdfdi2 = 474,
  CODE_FOR_lrintsfsi_di = 477,
  CODE_FOR_lrintdfsi_di = 478,
  CODE_FOR_btruncsf2 = 479,
  CODE_FOR_btruncdf2 = 480,
  CODE_FOR_ceilsf2 = 481,
  CODE_FOR_ceildf2 = 482,
  CODE_FOR_floorsf2 = 483,
  CODE_FOR_floordf2 = 484,
  CODE_FOR_roundsf2 = 485,
  CODE_FOR_rounddf2 = 486,
  CODE_FOR_stfiwx = 489,
  CODE_FOR_floatdidf2 = 490,
  CODE_FOR_floattikf2 = 491,
  CODE_FOR_floattitf2 = 492,
  CODE_FOR_floatunstikf2 = 493,
  CODE_FOR_floatunstitf2 = 494,
  CODE_FOR_fix_trunckfti2 = 495,
  CODE_FOR_fix_trunctfti2 = 496,
  CODE_FOR_fixuns_trunckfti2 = 497,
  CODE_FOR_fixuns_trunctfti2 = 498,
  CODE_FOR_floatdisf2_fcfids = 502,
  CODE_FOR_floatdisf2_internal1 = 504,
  CODE_FOR_floatunsdisf2_fcfidus = 505,
  CODE_FOR_one_cmplti2 = 558,
  CODE_FOR_one_cmplpti2 = 559,
  CODE_FOR_one_cmplv16qi2 = 560,
  CODE_FOR_one_cmplv8hi2 = 561,
  CODE_FOR_one_cmplv4si2 = 562,
  CODE_FOR_one_cmplv4sf2 = 563,
  CODE_FOR_one_cmplv2di2 = 564,
  CODE_FOR_one_cmplv2df2 = 565,
  CODE_FOR_one_cmplv1ti2 = 566,
  CODE_FOR_movsi_from_sf = 569,
  CODE_FOR_movsf_hardfloat = 582,
  CODE_FOR_movsd_hardfloat = 583,
  CODE_FOR_movsf_from_si = 586,
  CODE_FOR_movsf_from_si2_ashiftrt = 587,
  CODE_FOR_movsf_from_si2_lshiftrt = 588,
  CODE_FOR_xxspltidp_sf_internal = 597,
  CODE_FOR_xxspltidp_df_internal = 598,
  CODE_FOR_xxspltiw_sf_internal = 599,
  CODE_FOR_xxspltiw_df_internal = 600,
  CODE_FOR_extenddfif2_fprs = 611,
  CODE_FOR_extenddftf2_fprs = 612,
  CODE_FOR_extenddfif2_vsx = 613,
  CODE_FOR_extenddftf2_vsx = 614,
  CODE_FOR_truncifdf2_internal1 = 615,
  CODE_FOR_trunctfdf2_internal1 = 616,
  CODE_FOR_truncifdf2_internal2 = 617,
  CODE_FOR_trunctfdf2_internal2 = 618,
  CODE_FOR_fix_trunc_helperif = 619,
  CODE_FOR_fix_trunc_helpertf = 620,
  CODE_FOR_negif2_internal = 623,
  CODE_FOR_negtf2_internal = 624,
  CODE_FOR_ieee_128bit_vsx_negkf2 = 625,
  CODE_FOR_ieee_128bit_vsx_negtf2 = 626,
  CODE_FOR_ieee_128bit_vsx_abskf2 = 629,
  CODE_FOR_ieee_128bit_vsx_abstf2 = 630,
  CODE_FOR_p8_fmrgow_di = 643,
  CODE_FOR_p8_fmrgow_df = 644,
  CODE_FOR_p8_fmrgow_dd = 645,
  CODE_FOR_p8_mtvsrwz = 646,
  CODE_FOR_p8_mtvsrwz_v16qisi2 = 647,
  CODE_FOR_p8_mtvsrd_v16qidi2 = 648,
  CODE_FOR_reload_fpr_from_gprdi = 649,
  CODE_FOR_reload_fpr_from_gprdf = 650,
  CODE_FOR_reload_fpr_from_gprdd = 651,
  CODE_FOR_p8_mtvsrd_df = 652,
  CODE_FOR_p8_xxpermdi_ti = 653,
  CODE_FOR_p8_xxpermdi_v16qi = 654,
  CODE_FOR_p8_xxpermdi_v8hi = 655,
  CODE_FOR_p8_xxpermdi_v4si = 656,
  CODE_FOR_p8_xxpermdi_v4sf = 657,
  CODE_FOR_p8_xxpermdi_v2di = 658,
  CODE_FOR_p8_xxpermdi_v2df = 659,
  CODE_FOR_p8_xxpermdi_v1ti = 660,
  CODE_FOR_p8_xxpermdi_kf = 661,
  CODE_FOR_p8_xxpermdi_tf = 662,
  CODE_FOR_reload_vsx_from_gprti = 663,
  CODE_FOR_reload_vsx_from_gprv16qi = 664,
  CODE_FOR_reload_vsx_from_gprv8hi = 665,
  CODE_FOR_reload_vsx_from_gprv4si = 666,
  CODE_FOR_reload_vsx_from_gprv4sf = 667,
  CODE_FOR_reload_vsx_from_gprv2di = 668,
  CODE_FOR_reload_vsx_from_gprv2df = 669,
  CODE_FOR_reload_vsx_from_gprv1ti = 670,
  CODE_FOR_reload_vsx_from_gprkf = 671,
  CODE_FOR_reload_vsx_from_gprtf = 672,
  CODE_FOR_p8_mtvsrd_sf = 673,
  CODE_FOR_reload_vsx_from_gprsf = 674,
  CODE_FOR_p8_mfvsrd_3_ti = 675,
  CODE_FOR_p8_mfvsrd_3_v16qi = 676,
  CODE_FOR_p8_mfvsrd_3_v8hi = 677,
  CODE_FOR_p8_mfvsrd_3_v4si = 678,
  CODE_FOR_p8_mfvsrd_3_v4sf = 679,
  CODE_FOR_p8_mfvsrd_3_v2di = 680,
  CODE_FOR_p8_mfvsrd_3_v2df = 681,
  CODE_FOR_p8_mfvsrd_3_v1ti = 682,
  CODE_FOR_p8_mfvsrd_3_kf = 683,
  CODE_FOR_p8_mfvsrd_3_tf = 684,
  CODE_FOR_reload_gpr_from_vsxti = 685,
  CODE_FOR_reload_gpr_from_vsxv16qi = 686,
  CODE_FOR_reload_gpr_from_vsxv8hi = 687,
  CODE_FOR_reload_gpr_from_vsxv4si = 688,
  CODE_FOR_reload_gpr_from_vsxv4sf = 689,
  CODE_FOR_reload_gpr_from_vsxv2di = 690,
  CODE_FOR_reload_gpr_from_vsxv2df = 691,
  CODE_FOR_reload_gpr_from_vsxv1ti = 692,
  CODE_FOR_reload_gpr_from_vsxkf = 693,
  CODE_FOR_reload_gpr_from_vsxtf = 694,
  CODE_FOR_reload_gpr_from_vsxsf = 695,
  CODE_FOR_movdi_si_update = 704,
  CODE_FOR_movdi_di_update = 705,
  CODE_FOR_movdi_update_stack = 706,
  CODE_FOR_movsi_si_update = 711,
  CODE_FOR_movsi_di_update = 712,
  CODE_FOR_movsi_update_stack = 713,
   CODE_FOR_tls_dtprel_32 = CODE_FOR_nothing,
   CODE_FOR_tls_dtprel_64 = CODE_FOR_nothing,
   CODE_FOR_tls_dtprel_ha_32 = CODE_FOR_nothing,
   CODE_FOR_tls_dtprel_ha_64 = CODE_FOR_nothing,
   CODE_FOR_tls_dtprel_lo_32 = CODE_FOR_nothing,
   CODE_FOR_tls_dtprel_lo_64 = CODE_FOR_nothing,
   CODE_FOR_tls_got_dtprel_32 = CODE_FOR_nothing,
   CODE_FOR_tls_got_dtprel_64 = CODE_FOR_nothing,
   CODE_FOR_tls_tprel_32 = CODE_FOR_nothing,
   CODE_FOR_tls_tprel_64 = CODE_FOR_nothing,
   CODE_FOR_tls_tprel_ha_32 = CODE_FOR_nothing,
   CODE_FOR_tls_tprel_ha_64 = CODE_FOR_nothing,
   CODE_FOR_tls_tprel_lo_32 = CODE_FOR_nothing,
   CODE_FOR_tls_tprel_lo_64 = CODE_FOR_nothing,
   CODE_FOR_tls_got_tprel_32 = CODE_FOR_nothing,
   CODE_FOR_tls_got_tprel_64 = CODE_FOR_nothing,
   CODE_FOR_tls_tls_pcrel_32 = CODE_FOR_nothing,
   CODE_FOR_tls_tls_pcrel_64 = CODE_FOR_nothing,
   CODE_FOR_tls_tls_32 = CODE_FOR_nothing,
   CODE_FOR_tls_tls_64 = CODE_FOR_nothing,
   CODE_FOR_tls_get_tpointer_internal = CODE_FOR_nothing,
   CODE_FOR_tls_get_addr_internalsi = CODE_FOR_nothing,
   CODE_FOR_tls_get_addr_internaldi = CODE_FOR_nothing,
  CODE_FOR_load_toc_aix_si = 748,
  CODE_FOR_load_toc_aix_di = 749,
  CODE_FOR_load_toc_v4_pic_si = 750,
  CODE_FOR_load_toc_v4_PIC_1_normal = 751,
   CODE_FOR_load_toc_v4_PIC_1_476 = CODE_FOR_nothing,
  CODE_FOR_load_toc_v4_PIC_1b_normal = 752,
   CODE_FOR_load_toc_v4_PIC_1b_476 = CODE_FOR_nothing,
  CODE_FOR_load_toc_v4_PIC_2 = 753,
  CODE_FOR_load_toc_v4_PIC_3b = 754,
  CODE_FOR_load_toc_v4_PIC_3c = 755,
  CODE_FOR_elf_high = 761,
  CODE_FOR_elf_low = 762,
  CODE_FOR_blockage = 821,
  CODE_FOR_probe_stack_si = 822,
  CODE_FOR_probe_stack_di = 823,
  CODE_FOR_probe_stack_rangesi = 824,
  CODE_FOR_probe_stack_rangedi = 825,
  CODE_FOR_stack_protect_setsi = 826,
  CODE_FOR_stack_protect_setdi = 827,
  CODE_FOR_stack_protect_testsi = 828,
  CODE_FOR_stack_protect_testdi = 829,
  CODE_FOR_setsi_cc = 840,
  CODE_FOR_setdi_cc = 841,
  CODE_FOR_eqsisi2_isel = 842,
  CODE_FOR_nesisi2_isel = 843,
  CODE_FOR_ltsisi2_isel = 844,
  CODE_FOR_ltusisi2_isel = 845,
  CODE_FOR_gtsisi2_isel = 846,
  CODE_FOR_gtusisi2_isel = 847,
  CODE_FOR_lesisi2_isel = 848,
  CODE_FOR_leusisi2_isel = 849,
  CODE_FOR_gesisi2_isel = 850,
  CODE_FOR_geusisi2_isel = 851,
  CODE_FOR_eqdisi2_isel = 852,
  CODE_FOR_nedisi2_isel = 853,
  CODE_FOR_ltdisi2_isel = 854,
  CODE_FOR_ltudisi2_isel = 855,
  CODE_FOR_gtdisi2_isel = 856,
  CODE_FOR_gtudisi2_isel = 857,
  CODE_FOR_ledisi2_isel = 858,
  CODE_FOR_leudisi2_isel = 859,
  CODE_FOR_gedisi2_isel = 860,
  CODE_FOR_geudisi2_isel = 861,
  CODE_FOR_eqsidi2_isel = 862,
  CODE_FOR_nesidi2_isel = 863,
  CODE_FOR_ltsidi2_isel = 864,
  CODE_FOR_ltusidi2_isel = 865,
  CODE_FOR_gtsidi2_isel = 866,
  CODE_FOR_gtusidi2_isel = 867,
  CODE_FOR_lesidi2_isel = 868,
  CODE_FOR_leusidi2_isel = 869,
  CODE_FOR_gesidi2_isel = 870,
  CODE_FOR_geusidi2_isel = 871,
  CODE_FOR_eqdidi2_isel = 872,
  CODE_FOR_nedidi2_isel = 873,
  CODE_FOR_ltdidi2_isel = 874,
  CODE_FOR_ltudidi2_isel = 875,
  CODE_FOR_gtdidi2_isel = 876,
  CODE_FOR_gtudidi2_isel = 877,
  CODE_FOR_ledidi2_isel = 878,
  CODE_FOR_leudidi2_isel = 879,
  CODE_FOR_gedidi2_isel = 880,
  CODE_FOR_geudidi2_isel = 881,
  CODE_FOR_cceq_ior_compare_si = 924,
  CODE_FOR_cceq_ior_compare_di = 925,
  CODE_FOR_cceq_ior_compare_complement = 926,
  CODE_FOR_cceq_rev_compare_si = 927,
  CODE_FOR_cceq_rev_compare_di = 928,
  CODE_FOR_jump = 930,
  CODE_FOR_return = 931,
  CODE_FOR_simple_return = 932,
  CODE_FOR_indirect_jumpsi_nospec = 935,
  CODE_FOR_indirect_jumpdi_nospec = 936,
  CODE_FOR_tablejumpsi_insn_normal = 937,
  CODE_FOR_tablejumpdi_insn_normal = 938,
  CODE_FOR_tablejumpsi_insn_nospec = 939,
  CODE_FOR_tablejumpdi_insn_nospec = 940,
  CODE_FOR_nop = 941,
  CODE_FOR_group_ending_nop = 942,
  CODE_FOR_speculation_barrier = 943,
  CODE_FOR_bdz_si = 944,
  CODE_FOR_bdnz_si = 945,
  CODE_FOR_bdz_di = 946,
  CODE_FOR_bdnz_di = 947,
  CODE_FOR_bdztf_si = 948,
  CODE_FOR_bdnztf_si = 949,
  CODE_FOR_bdztf_di = 950,
  CODE_FOR_bdnztf_di = 951,
  CODE_FOR_trap = 952,
  CODE_FOR_prologue_movesi_from_cr = 956,
  CODE_FOR_stack_tie = 971,
  CODE_FOR_stack_restore_tie = 972,
  CODE_FOR_eh_set_lr_si = 998,
  CODE_FOR_eh_set_lr_di = 999,
  CODE_FOR_eh_return_internal = 1000,
  CODE_FOR_prefetch = 1001,
  CODE_FOR_load_split_stack_limit_di = 1002,
  CODE_FOR_load_split_stack_limit_si = 1003,
  CODE_FOR_split_stack_return = 1004,
  CODE_FOR_bpermd_si = 1005,
  CODE_FOR_bpermd_di = 1006,
  CODE_FOR_rs6000_get_timebase_ppc32 = 1015,
  CODE_FOR_rs6000_mftb_si = 1016,
  CODE_FOR_rs6000_mftb_di = 1017,
  CODE_FOR_rs6000_mffsl_hw = 1018,
  CODE_FOR_rs6000_mffs = 1019,
  CODE_FOR_rs6000_mtfsf = 1020,
  CODE_FOR_rs6000_mtfsf_hi = 1021,
  CODE_FOR_addg6s = 1026,
  CODE_FOR_cdtbcd = 1027,
  CODE_FOR_cbcdtd = 1028,
  CODE_FOR_dive_si = 1029,
  CODE_FOR_diveu_si = 1030,
  CODE_FOR_dive_di = 1031,
  CODE_FOR_diveu_di = 1032,
  CODE_FOR_unpacktf_dm = 1033,
  CODE_FOR_unpackif_dm = 1034,
  CODE_FOR_unpacktd_dm = 1035,
  CODE_FOR_unpacktf_nodm = 1036,
  CODE_FOR_unpackif_nodm = 1037,
  CODE_FOR_unpacktd_nodm = 1038,
  CODE_FOR_packtf_hard = 1039,
  CODE_FOR_packif_hard = 1040,
  CODE_FOR_packtd_hard = 1041,
  CODE_FOR_packtf_soft = 1042,
   CODE_FOR_packif_soft = CODE_FOR_nothing,
   CODE_FOR_packtd_soft = CODE_FOR_nothing,
  CODE_FOR_unpackv1ti = 1043,
  CODE_FOR_unpackkf = 1044,
  CODE_FOR_packv1ti = 1045,
  CODE_FOR_packkf = 1046,
  CODE_FOR_addkf3 = 1047,
  CODE_FOR_addtf3 = 1048,
  CODE_FOR_subkf3 = 1049,
  CODE_FOR_subtf3 = 1050,
  CODE_FOR_mulkf3 = 1051,
  CODE_FOR_multf3 = 1052,
  CODE_FOR_divkf3 = 1053,
  CODE_FOR_divtf3 = 1054,
  CODE_FOR_sqrtkf2 = 1055,
  CODE_FOR_sqrttf2 = 1056,
  CODE_FOR_copysignkf3_hard = 1057,
  CODE_FOR_copysigntf3_hard = 1058,
  CODE_FOR_copysignkf3_soft = 1059,
  CODE_FOR_copysigntf3_soft = 1060,
  CODE_FOR_negkf2_hw = 1061,
  CODE_FOR_negtf2_hw = 1062,
  CODE_FOR_abskf2_hw = 1063,
  CODE_FOR_abstf2_hw = 1064,
  CODE_FOR_fmakf4_hw = 1067,
  CODE_FOR_fmatf4_hw = 1068,
  CODE_FOR_extendsfkf2_hw = 1075,
  CODE_FOR_extendsftf2_hw = 1076,
  CODE_FOR_extenddfkf2_hw = 1077,
  CODE_FOR_extenddftf2_hw = 1078,
  CODE_FOR_trunckfdf2_hw = 1081,
  CODE_FOR_trunctfdf2_hw = 1082,
  CODE_FOR_trunckfsf2_hw = 1083,
  CODE_FOR_trunctfsf2_hw = 1084,
  CODE_FOR_fix_kfsi2_hw = 1085,
  CODE_FOR_fixuns_kfsi2_hw = 1086,
  CODE_FOR_fix_tfsi2_hw = 1087,
  CODE_FOR_fixuns_tfsi2_hw = 1088,
  CODE_FOR_fix_kfdi2_hw = 1089,
  CODE_FOR_fixuns_kfdi2_hw = 1090,
  CODE_FOR_fix_tfdi2_hw = 1091,
  CODE_FOR_fixuns_tfdi2_hw = 1092,
  CODE_FOR_fix_trunckfqi2 = 1093,
  CODE_FOR_fixuns_trunckfqi2 = 1094,
  CODE_FOR_fix_trunckfhi2 = 1095,
  CODE_FOR_fixuns_trunckfhi2 = 1096,
  CODE_FOR_fix_trunctfqi2 = 1097,
  CODE_FOR_fixuns_trunctfqi2 = 1098,
  CODE_FOR_fix_trunctfhi2 = 1099,
  CODE_FOR_fixuns_trunctfhi2 = 1100,
  CODE_FOR_float_kfdi2_hw = 1113,
  CODE_FOR_float_tfdi2_hw = 1114,
  CODE_FOR_float_kfsi2_hw = 1115,
  CODE_FOR_float_tfsi2_hw = 1116,
  CODE_FOR_floatqikf2 = 1117,
  CODE_FOR_floathikf2 = 1118,
  CODE_FOR_floatqitf2 = 1119,
  CODE_FOR_floathitf2 = 1120,
  CODE_FOR_floatuns_kfdi2_hw = 1121,
  CODE_FOR_floatuns_tfdi2_hw = 1122,
  CODE_FOR_floatuns_kfsi2_hw = 1123,
  CODE_FOR_floatuns_tfsi2_hw = 1124,
  CODE_FOR_floatunsqikf2 = 1125,
  CODE_FOR_floatunshikf2 = 1126,
  CODE_FOR_floatunsqitf2 = 1127,
  CODE_FOR_floatunshitf2 = 1128,
  CODE_FOR_floorkf2 = 1129,
  CODE_FOR_floortf2 = 1130,
  CODE_FOR_ceilkf2 = 1131,
  CODE_FOR_ceiltf2 = 1132,
  CODE_FOR_btrunckf2 = 1133,
  CODE_FOR_btrunctf2 = 1134,
  CODE_FOR_roundkf2 = 1135,
  CODE_FOR_roundtf2 = 1136,
  CODE_FOR_addkf3_odd = 1137,
  CODE_FOR_addtf3_odd = 1138,
  CODE_FOR_subkf3_odd = 1139,
  CODE_FOR_subtf3_odd = 1140,
  CODE_FOR_mulkf3_odd = 1141,
  CODE_FOR_multf3_odd = 1142,
  CODE_FOR_divkf3_odd = 1143,
  CODE_FOR_divtf3_odd = 1144,
  CODE_FOR_sqrtkf2_odd = 1145,
  CODE_FOR_sqrttf2_odd = 1146,
  CODE_FOR_fmakf4_odd = 1147,
  CODE_FOR_fmatf4_odd = 1148,
  CODE_FOR_trunckfdf2_odd = 1155,
  CODE_FOR_trunctfdf2_odd = 1156,
  CODE_FOR_darnsi = 1159,
  CODE_FOR_darndi = 1160,
  CODE_FOR_setb_signed = 1162,
  CODE_FOR_setb_unsigned = 1163,
  CODE_FOR_hashst = 1166,
  CODE_FOR_hashchk = 1167,
  CODE_FOR_isync = 1170,
  CODE_FOR_loadsync_qi = 1171,
  CODE_FOR_loadsync_hi = 1172,
  CODE_FOR_loadsync_si = 1173,
  CODE_FOR_loadsync_di = 1174,
  CODE_FOR_loadsync_ti = 1175,
  CODE_FOR_load_quadpti = 1176,
  CODE_FOR_store_quadpti = 1177,
  CODE_FOR_load_lockedqi = 1178,
  CODE_FOR_load_lockedhi = 1179,
  CODE_FOR_load_lockedsi = 1180,
  CODE_FOR_load_lockeddi = 1181,
  CODE_FOR_load_lockedqi_si = 1182,
  CODE_FOR_load_lockedhi_si = 1183,
  CODE_FOR_load_lockedpti = 1184,
  CODE_FOR_store_conditionalqi = 1185,
  CODE_FOR_store_conditionalhi = 1186,
  CODE_FOR_store_conditionalsi = 1187,
  CODE_FOR_store_conditionaldi = 1188,
  CODE_FOR_store_conditionalpti = 1189,
  CODE_FOR_vector_ltv4sf = 1190,
  CODE_FOR_vector_lev4sf = 1191,
  CODE_FOR_vector_nev4sf = 1192,
  CODE_FOR_vector_ungtv4sf = 1193,
  CODE_FOR_vector_ungev4sf = 1194,
  CODE_FOR_vector_unltv4sf = 1195,
  CODE_FOR_vector_unlev4sf = 1196,
  CODE_FOR_vector_ltv2df = 1197,
  CODE_FOR_vector_lev2df = 1198,
  CODE_FOR_vector_nev2df = 1199,
  CODE_FOR_vector_ungtv2df = 1200,
  CODE_FOR_vector_ungev2df = 1201,
  CODE_FOR_vector_unltv2df = 1202,
  CODE_FOR_vector_unlev2df = 1203,
  CODE_FOR_vector_ltgtv4sf = 1204,
  CODE_FOR_vector_uneqv4sf = 1205,
  CODE_FOR_vector_unorderedv4sf = 1206,
  CODE_FOR_vector_orderedv4sf = 1207,
  CODE_FOR_vector_ltgtv2df = 1208,
  CODE_FOR_vector_uneqv2df = 1209,
  CODE_FOR_vector_unorderedv2df = 1210,
  CODE_FOR_vector_orderedv2df = 1211,
  CODE_FOR_xxspltib_v16qi = 1237,
  CODE_FOR_xxspltib_v8hi_nosplit = 1238,
  CODE_FOR_xxspltib_v4si_nosplit = 1239,
  CODE_FOR_xxspltib_v2di_nosplit = 1240,
  CODE_FOR_vsx_movv16qi_64bit = 1245,
  CODE_FOR_vsx_movv8hi_64bit = 1246,
  CODE_FOR_vsx_movv4si_64bit = 1247,
  CODE_FOR_vsx_movv2di_64bit = 1248,
  CODE_FOR_vsx_movv4sf_64bit = 1249,
  CODE_FOR_vsx_movv2df_64bit = 1250,
  CODE_FOR_vsx_movv1ti_64bit = 1251,
  CODE_FOR_vsx_movkf_64bit = 1252,
  CODE_FOR_vsx_movtf_64bit = 1253,
  CODE_FOR_vsx_movti_64bit = 1254,
  CODE_FOR_vsx_lxvrbx = 1265,
  CODE_FOR_vsx_lxvrhx = 1266,
  CODE_FOR_vsx_lxvrwx = 1267,
  CODE_FOR_vsx_lxvrdx = 1268,
  CODE_FOR_vsx_stxvrbx = 1269,
  CODE_FOR_vsx_stxvrhx = 1270,
  CODE_FOR_vsx_stxvrwx = 1271,
  CODE_FOR_vsx_stxvrdx = 1272,
  CODE_FOR_vsx_ld_elemrev_v2di = 1273,
  CODE_FOR_vsx_ld_elemrev_v1ti = 1274,
  CODE_FOR_vsx_ld_elemrev_v2df = 1275,
  CODE_FOR_vsx_ld_elemrev_v4si = 1276,
  CODE_FOR_vsx_ld_elemrev_v4sf = 1277,
  CODE_FOR_vsx_ld_elemrev_v16qi_internal = 1279,
  CODE_FOR_vsx_st_elemrev_v1ti = 1280,
  CODE_FOR_vsx_st_elemrev_v2df = 1281,
  CODE_FOR_vsx_st_elemrev_v2di = 1282,
  CODE_FOR_vsx_st_elemrev_v4sf = 1283,
  CODE_FOR_vsx_st_elemrev_v4si = 1284,
  CODE_FOR_vsx_mul_v2di = 1294,
  CODE_FOR_vsx_div_v2di = 1297,
  CODE_FOR_vsx_udiv_v2di = 1298,
  CODE_FOR_vsx_div_v1ti = 1299,
  CODE_FOR_vsx_udiv_v1ti = 1300,
  CODE_FOR_vsx_dives_v1ti = 1301,
  CODE_FOR_vsx_diveu_v1ti = 1302,
  CODE_FOR_vsx_mods_v1ti = 1303,
  CODE_FOR_vsx_modu_v1ti = 1304,
  CODE_FOR_vsx_frev4sf2 = 1308,
  CODE_FOR_vsx_frev2df2 = 1309,
  CODE_FOR_vsx_nabsv4sf2 = 1314,
  CODE_FOR_vsx_nabsv2df2 = 1315,
  CODE_FOR_vsx_smaxv4sf3 = 1316,
  CODE_FOR_vsx_smaxv2df3 = 1317,
  CODE_FOR_vsx_eqv4sf = 1335,
  CODE_FOR_vsx_eqv2df = 1336,
  CODE_FOR_vsx_gtv4sf = 1337,
  CODE_FOR_vsx_gtv2df = 1338,
  CODE_FOR_vsx_copysignv4sf3 = 1348,
  CODE_FOR_vsx_copysignv2df3 = 1349,
  CODE_FOR_vsx_floatv4siv4sf2 = 1350,
  CODE_FOR_vsx_floatv2div2df2 = 1351,
  CODE_FOR_vsx_floatunsv4siv4sf2 = 1352,
  CODE_FOR_vsx_floatunsv2div2df2 = 1353,
  CODE_FOR_vsx_fix_truncv4sfv4si2 = 1354,
  CODE_FOR_vsx_fix_truncv2dfv2di2 = 1355,
  CODE_FOR_vsx_fixuns_truncv4sfv4si2 = 1356,
  CODE_FOR_vsx_fixuns_truncv2dfv2di2 = 1357,
  CODE_FOR_vsx_xsrdpi = 1358,
  CODE_FOR_vsx_xvrspi = 1359,
  CODE_FOR_vsx_xvrdpi = 1360,
  CODE_FOR_vsx_xsrdpic = 1361,
  CODE_FOR_vsx_xvrspic = 1362,
  CODE_FOR_vsx_xvrdpic = 1363,
  CODE_FOR_vsx_btruncv4sf2 = 1364,
  CODE_FOR_vsx_btruncv2df2 = 1365,
  CODE_FOR_vsx_floorv4sf2 = 1369,
  CODE_FOR_vsx_floorv2df2 = 1370,
  CODE_FOR_vsx_ceilv4sf2 = 1371,
  CODE_FOR_vsx_ceilv2df2 = 1372,
  CODE_FOR_vsx_xscvdpsp = 1373,
  CODE_FOR_vsx_xvcvspdp_be = 1374,
  CODE_FOR_vsx_xvcvspdp_le = 1375,
  CODE_FOR_vsx_xvcvdpsp = 1376,
  CODE_FOR_vsx_xscvspdp = 1377,
  CODE_FOR_vsx_xscvspdp_scalar2 = 1378,
  CODE_FOR_vsx_xvcvhpsp = 1379,
  CODE_FOR_vsx_xvcvsphp = 1380,
  CODE_FOR_vsx_xscvdpsp_scalar = 1381,
  CODE_FOR_vsx_xscvdpspn = 1382,
  CODE_FOR_vsx_xscvspdpn = 1383,
  CODE_FOR_vsx_xscvdpspn_scalar = 1384,
  CODE_FOR_vsx_xscvspdpn_directmove = 1385,
  CODE_FOR_vsx_xvcvsxwsp = 1386,
  CODE_FOR_vsx_xvcvuxwsp = 1387,
  CODE_FOR_vsx_xvcvsxddp = 1388,
  CODE_FOR_vsx_xvcvuxddp = 1389,
  CODE_FOR_vsx_xvcvspsxws = 1390,
  CODE_FOR_vsx_xvcvspuxws = 1391,
  CODE_FOR_vsx_xvcvdpsxds = 1392,
  CODE_FOR_vsx_xvcvdpuxds = 1393,
  CODE_FOR_vsx_xvcvdpsxws = 1394,
  CODE_FOR_vsx_xvcvdpuxws = 1395,
  CODE_FOR_vsx_xvcvsxdsp = 1396,
  CODE_FOR_vsx_xvcvuxdsp = 1397,
  CODE_FOR_vsx_xvcvsxwdp_be = 1398,
  CODE_FOR_vsx_xvcvuxwdp_be = 1399,
  CODE_FOR_vsx_xvcvsxwdp_le = 1400,
  CODE_FOR_vsx_xvcvuxwdp_le = 1401,
  CODE_FOR_vsx_xvcvsxwdp_df = 1402,
  CODE_FOR_vsx_xvcvuxwdp_df = 1403,
  CODE_FOR_vsx_xvcvspsxds_be = 1404,
  CODE_FOR_vsx_xvcvspuxds_be = 1405,
  CODE_FOR_vsx_xvcvspsxds_le = 1406,
  CODE_FOR_vsx_xvcvspuxds_le = 1407,
  CODE_FOR_vsx_concat_v2df = 1409,
  CODE_FOR_vsx_concat_v2di = 1410,
  CODE_FOR_vsx_concat_v2sf = 1417,
  CODE_FOR_xxswapd_v16qi = 1420,
  CODE_FOR_xxswapd_v8hi = 1421,
  CODE_FOR_xxswapd_v4sf = 1422,
  CODE_FOR_xxswapd_v4si = 1423,
  CODE_FOR_xxswapd_v2df = 1424,
  CODE_FOR_xxswapd_v2di = 1425,
  CODE_FOR_xxswapd_v1ti = 1426,
  CODE_FOR_xxgenpcvm_v16qi_internal = 1427,
  CODE_FOR_xxgenpcvm_v8hi_internal = 1428,
  CODE_FOR_xxgenpcvm_v4si_internal = 1429,
  CODE_FOR_xxgenpcvm_v2di_internal = 1430,
  CODE_FOR_vsx_stxvd2x4_le_const_v4sf = 1441,
  CODE_FOR_vsx_stxvd2x4_le_const_v4si = 1442,
  CODE_FOR_vsx_vslo_v2df = 1455,
  CODE_FOR_vsx_vslo_v2di = 1456,
  CODE_FOR_vsx_extract_v2df_var = 1457,
  CODE_FOR_vsx_extract_v2di_var = 1458,
  CODE_FOR_vsx_extract_v4sf = 1461,
  CODE_FOR_vsx_extract_v4sf_var = 1464,
  CODE_FOR_vsx_xxpermdi2_v2df_1 = 1466,
  CODE_FOR_vsx_xxpermdi2_v2di_1 = 1467,
  CODE_FOR_vsx_extract_v4si_w1 = 1468,
  CODE_FOR_vsx_extract_v16qi_p9 = 1470,
  CODE_FOR_vsx_extract_v8hi_p9 = 1471,
  CODE_FOR_vsx_extract_v4si_p9 = 1472,
  CODE_FOR_vsx_extract_v16qi_var = 1485,
  CODE_FOR_vsx_extract_v8hi_var = 1486,
  CODE_FOR_vsx_extract_v4si_var = 1487,
  CODE_FOR_vextractlv16qi_internal = 1491,
  CODE_FOR_vextractlv8hi_internal = 1492,
  CODE_FOR_vextractlv4si_internal = 1493,
  CODE_FOR_vextractlv2di_internal = 1494,
  CODE_FOR_vextractrv16qi_internal = 1495,
  CODE_FOR_vextractrv8hi_internal = 1496,
  CODE_FOR_vextractrv4si_internal = 1497,
  CODE_FOR_vextractrv2di_internal = 1498,
  CODE_FOR_vinsertvl_internal_v16qi = 1499,
  CODE_FOR_vinsertvl_internal_v8hi = 1500,
  CODE_FOR_vinsertvl_internal_v4si = 1501,
  CODE_FOR_vinsertvl_internal_v2di = 1502,
  CODE_FOR_vinsertvr_internal_v16qi = 1503,
  CODE_FOR_vinsertvr_internal_v8hi = 1504,
  CODE_FOR_vinsertvr_internal_v4si = 1505,
  CODE_FOR_vinsertvr_internal_v2di = 1506,
  CODE_FOR_vinsertgl_internal_v16qi = 1507,
  CODE_FOR_vinsertgl_internal_v8hi = 1508,
  CODE_FOR_vinsertgl_internal_v4si = 1509,
  CODE_FOR_vinsertgl_internal_v2di = 1510,
  CODE_FOR_vinsertgr_internal_v16qi = 1511,
  CODE_FOR_vinsertgr_internal_v8hi = 1512,
  CODE_FOR_vinsertgr_internal_v4si = 1513,
  CODE_FOR_vinsertgr_internal_v2di = 1514,
  CODE_FOR_vreplace_elt_v4si_inst = 1515,
  CODE_FOR_vreplace_elt_v4sf_inst = 1516,
  CODE_FOR_vreplace_elt_v2di_inst = 1517,
  CODE_FOR_vreplace_elt_v2df_inst = 1518,
  CODE_FOR_vreplace_un_si = 1519,
  CODE_FOR_vreplace_un_sf = 1520,
  CODE_FOR_vreplace_un_di = 1521,
  CODE_FOR_vreplace_un_df = 1522,
  CODE_FOR_vsx_set_v16qi_p9 = 1557,
  CODE_FOR_vsx_set_v8hi_p9 = 1558,
  CODE_FOR_vsx_set_v4si_p9 = 1559,
  CODE_FOR_vsx_set_v4sf_p9 = 1560,
  CODE_FOR_vsx_splat_v2df_reg = 1564,
  CODE_FOR_vsx_splat_v2di_reg = 1565,
  CODE_FOR_vsx_splat_v2df_mem = 1566,
  CODE_FOR_vsx_splat_v2di_mem = 1567,
  CODE_FOR_vsx_splat_v4si = 1568,
  CODE_FOR_vsx_splat_v4si_di = 1569,
  CODE_FOR_vsx_splat_v4sf = 1570,
  CODE_FOR_vsx_xxspltw_v4sf = 1571,
  CODE_FOR_vsx_xxspltw_v4si = 1572,
  CODE_FOR_vsx_xxspltw_v4sf_direct = 1573,
  CODE_FOR_vsx_xxspltw_v4si_direct = 1574,
  CODE_FOR_vsx_vspltb_di = 1575,
  CODE_FOR_vsx_vsplth_di = 1576,
  CODE_FOR_vsx_xxspltd_v2df = 1577,
  CODE_FOR_vsx_xxspltd_v2di = 1578,
  CODE_FOR_vsx_xxsldwi_v16qi = 1579,
  CODE_FOR_vsx_xxsldwi_v8hi = 1580,
  CODE_FOR_vsx_xxsldwi_v4si = 1581,
  CODE_FOR_vsx_xxsldwi_v2di = 1582,
  CODE_FOR_vsx_xxsldwi_v4sf = 1583,
  CODE_FOR_vsx_xxsldwi_v2df = 1584,
  CODE_FOR_vsx_xxsldwi_v1ti = 1585,
  CODE_FOR_vsx_xxsldwi_ti = 1586,
  CODE_FOR_vsx_xxsldwi_kf = 1587,
  CODE_FOR_vsx_xxsldwi_tf = 1588,
  CODE_FOR_vsx_reduc_plus_v2df = 1589,
  CODE_FOR_vsx_reduc_smin_v2df = 1590,
  CODE_FOR_vsx_reduc_smax_v2df = 1591,
  CODE_FOR_vsx_reduc_plus_v4sf = 1592,
  CODE_FOR_vsx_reduc_smin_v4sf = 1593,
  CODE_FOR_vsx_reduc_smax_v4sf = 1594,
  CODE_FOR_vsx_sign_extend_v2di_v1ti = 1601,
  CODE_FOR_vsx_sign_extend_v16qi_v4si = 1602,
  CODE_FOR_vsx_sign_extend_v16qi_v2di = 1603,
  CODE_FOR_vsx_sign_extend_v16qi_di = 1604,
  CODE_FOR_vsx_sign_extend_v16qi_si = 1605,
  CODE_FOR_vsx_sign_extend_v8hi_v4si = 1606,
  CODE_FOR_vsx_sign_extend_v8hi_v2di = 1607,
  CODE_FOR_vsx_sign_extend_v8hi_di = 1608,
  CODE_FOR_vsx_sign_extend_v8hi_si = 1609,
  CODE_FOR_vsx_sign_extend_v4si_v2di = 1610,
  CODE_FOR_extendditi2 = 1611,
  CODE_FOR_extendditi2_vector = 1612,
  CODE_FOR_xsxexpqp_kf_v2di = 1613,
  CODE_FOR_xsxexpqp_kf_di = 1614,
  CODE_FOR_xsxexpqp_tf_v2di = 1615,
  CODE_FOR_xsxexpqp_tf_di = 1616,
  CODE_FOR_xsxexpdp_si = 1617,
  CODE_FOR_xsxexpdp_di = 1618,
  CODE_FOR_xsxsigqp_kf_v1ti = 1619,
  CODE_FOR_xsxsigqp_tf_v1ti = 1620,
  CODE_FOR_xsxsigqp_kf_ti = 1621,
  CODE_FOR_xsxsigqp_tf_ti = 1622,
  CODE_FOR_xsxsigdp = 1623,
  CODE_FOR_xsiexpqpf_kf = 1624,
  CODE_FOR_xsiexpqpf_tf = 1625,
  CODE_FOR_xsiexpqp_kf_v2di = 1626,
  CODE_FOR_xsiexpqp_kf_di = 1627,
  CODE_FOR_xsiexpqp_tf_v2di = 1628,
  CODE_FOR_xsiexpqp_tf_di = 1629,
  CODE_FOR_xsiexpdp_si = 1630,
  CODE_FOR_xsiexpdp_di = 1631,
  CODE_FOR_xsiexpdpf_si = 1632,
  CODE_FOR_xsiexpdpf_di = 1633,
  CODE_FOR_xvxexpsp = 1641,
  CODE_FOR_xvxexpdp = 1642,
  CODE_FOR_xvxsigsp = 1643,
  CODE_FOR_xvxsigdp = 1644,
  CODE_FOR_xviexpsp = 1645,
  CODE_FOR_xviexpdp = 1646,
  CODE_FOR_xvtstdcsp = 1647,
  CODE_FOR_xvtstdcdp = 1648,
  CODE_FOR_lxvll = 1656,
  CODE_FOR_stxvll = 1657,
  CODE_FOR_vcmpneb = 1659,
  CODE_FOR_vcmpnezb = 1660,
  CODE_FOR_vcmpnezb_p = 1661,
  CODE_FOR_vcmpneh = 1662,
  CODE_FOR_vcmpnezh = 1663,
  CODE_FOR_vcmpnew = 1664,
  CODE_FOR_vcmpnezw = 1665,
  CODE_FOR_vclzlsbb_v16qi = 1672,
  CODE_FOR_vctzlsbb_v16qi = 1673,
  CODE_FOR_vclzlsbb_v8hi = 1674,
  CODE_FOR_vctzlsbb_v8hi = 1675,
  CODE_FOR_vclzlsbb_v4si = 1676,
  CODE_FOR_vctzlsbb_v4si = 1677,
  CODE_FOR_vextublx = 1678,
  CODE_FOR_vextubrx = 1679,
  CODE_FOR_vextuhlx = 1680,
  CODE_FOR_vextuhrx = 1681,
  CODE_FOR_vextuwlx = 1682,
  CODE_FOR_vextuwrx = 1683,
  CODE_FOR_extract4b = 1684,
  CODE_FOR_p9_xxbrq_v1ti = 1686,
  CODE_FOR_p9_xxbrd_v2di = 1687,
  CODE_FOR_p9_xxbrw_v4si = 1688,
  CODE_FOR_p9_xxbrh_v8hi = 1689,
  CODE_FOR_vsx_xvcvspbf16 = 1690,
  CODE_FOR_vsx_xvcvbf16spn = 1691,
  CODE_FOR_vec_mtvsrbmi = 1692,
  CODE_FOR_vec_mtvsr_v16qi = 1693,
  CODE_FOR_vec_mtvsr_v8hi = 1694,
  CODE_FOR_vec_mtvsr_v4si = 1695,
  CODE_FOR_vec_mtvsr_v2di = 1696,
  CODE_FOR_vec_mtvsr_v1ti = 1697,
  CODE_FOR_vec_cntmb_v16qi = 1698,
  CODE_FOR_vec_cntmb_v8hi = 1699,
  CODE_FOR_vec_cntmb_v4si = 1700,
  CODE_FOR_vec_cntmb_v2di = 1701,
  CODE_FOR_vec_extract_v16qi = 1702,
  CODE_FOR_vec_extract_v8hi = 1703,
  CODE_FOR_vec_extract_v4si = 1704,
  CODE_FOR_vec_extract_v2di = 1705,
  CODE_FOR_vec_extract_v1ti = 1706,
  CODE_FOR_vec_expand_v16qi = 1707,
  CODE_FOR_vec_expand_v8hi = 1708,
  CODE_FOR_vec_expand_v4si = 1709,
  CODE_FOR_vec_expand_v2di = 1710,
  CODE_FOR_vec_expand_v1ti = 1711,
  CODE_FOR_dives_v2di = 1712,
  CODE_FOR_dives_v4si = 1713,
  CODE_FOR_diveu_v2di = 1714,
  CODE_FOR_diveu_v4si = 1715,
  CODE_FOR_divv2di3 = 1716,
  CODE_FOR_divv4si3 = 1717,
  CODE_FOR_udivv2di3 = 1718,
  CODE_FOR_udivv4si3 = 1719,
  CODE_FOR_modv2di3 = 1720,
  CODE_FOR_modv4si3 = 1721,
  CODE_FOR_umodv2di3 = 1722,
  CODE_FOR_umodv4si3 = 1723,
  CODE_FOR_smulv2di3_highpart = 1724,
  CODE_FOR_smulv4si3_highpart = 1725,
  CODE_FOR_umulv2di3_highpart = 1726,
  CODE_FOR_umulv4si3_highpart = 1727,
  CODE_FOR_mulv2di3 = 1728,
  CODE_FOR_xxspltiw_v4si = 1729,
  CODE_FOR_xxspltiw_v4sf_inst = 1730,
  CODE_FOR_xxspltidp_v2df_inst = 1731,
  CODE_FOR_xxsplti32dx_v4si_inst = 1732,
  CODE_FOR_xxsplti32dx_v4sf_inst = 1733,
  CODE_FOR_xxblend_v4si = 1734,
  CODE_FOR_xxblend_v8hi = 1735,
  CODE_FOR_xxblend_v16qi = 1736,
  CODE_FOR_xxblend_v4sf = 1737,
  CODE_FOR_xxblend_v2df = 1738,
  CODE_FOR_xxblend_v2di = 1739,
  CODE_FOR_xxpermx_inst = 1740,
  CODE_FOR_xxeval = 1741,
  CODE_FOR_vmsumcud = 1742,
  CODE_FOR_sldoi_to_movv4si = 1753,
  CODE_FOR_sldoi_to_movv8hi = 1754,
  CODE_FOR_sldoi_to_movv16qi = 1755,
  CODE_FOR_sldoi_to_movv4sf = 1756,
  CODE_FOR_sldoi_to_movv2df = 1757,
  CODE_FOR_sldoi_to_movv2di = 1758,
  CODE_FOR_sldoi_to_movv1ti = 1759,
  CODE_FOR_sldoi_to_movti = 1760,
  CODE_FOR_sldoi_to_movkf = 1761,
  CODE_FOR_sldoi_to_movtf = 1762,
  CODE_FOR_get_vrsave_internal = 1763,
  CODE_FOR_addv4si3 = 1773,
  CODE_FOR_addv8hi3 = 1774,
  CODE_FOR_addv16qi3 = 1775,
  CODE_FOR_addv2di3 = 1776,
  CODE_FOR_altivec_vaddcuw = 1778,
  CODE_FOR_altivec_vadduws = 1779,
  CODE_FOR_altivec_vadduhs = 1780,
  CODE_FOR_altivec_vaddubs = 1781,
  CODE_FOR_altivec_vaddsws = 1782,
  CODE_FOR_altivec_vaddshs = 1783,
  CODE_FOR_altivec_vaddsbs = 1784,
  CODE_FOR_subv4si3 = 1785,
  CODE_FOR_subv8hi3 = 1786,
  CODE_FOR_subv16qi3 = 1787,
  CODE_FOR_subv2di3 = 1788,
  CODE_FOR_altivec_vsubcuw = 1790,
  CODE_FOR_altivec_vsubuws = 1791,
  CODE_FOR_altivec_vsubuhs = 1792,
  CODE_FOR_altivec_vsububs = 1793,
  CODE_FOR_altivec_vsubsws = 1794,
  CODE_FOR_altivec_vsubshs = 1795,
  CODE_FOR_altivec_vsubsbs = 1796,
  CODE_FOR_uavgv4si3_ceil = 1797,
  CODE_FOR_uavgv8hi3_ceil = 1798,
  CODE_FOR_uavgv16qi3_ceil = 1799,
  CODE_FOR_avgv4si3_ceil = 1800,
  CODE_FOR_avgv8hi3_ceil = 1801,
  CODE_FOR_avgv16qi3_ceil = 1802,
  CODE_FOR_altivec_vcmpbfp = 1803,
  CODE_FOR_altivec_eqv1ti = 1804,
  CODE_FOR_altivec_eqv4si = 1805,
  CODE_FOR_altivec_eqv8hi = 1806,
  CODE_FOR_altivec_eqv16qi = 1807,
  CODE_FOR_altivec_eqv2di = 1808,
  CODE_FOR_altivec_vselv4si = 1822,
  CODE_FOR_altivec_vselv8hi = 1823,
  CODE_FOR_altivec_vselv16qi = 1824,
  CODE_FOR_altivec_vselv4sf = 1825,
  CODE_FOR_altivec_vselv2df = 1826,
  CODE_FOR_altivec_vselv2di = 1827,
  CODE_FOR_altivec_vselv1ti = 1828,
  CODE_FOR_altivec_vselti = 1829,
  CODE_FOR_altivec_vselkf = 1830,
  CODE_FOR_altivec_vseltf = 1831,
  CODE_FOR_altivec_vselv4si2 = 1832,
  CODE_FOR_altivec_vselv8hi2 = 1833,
  CODE_FOR_altivec_vselv16qi2 = 1834,
  CODE_FOR_altivec_vselv4sf2 = 1835,
  CODE_FOR_altivec_vselv2df2 = 1836,
  CODE_FOR_altivec_vselv2di2 = 1837,
  CODE_FOR_altivec_vselv1ti2 = 1838,
  CODE_FOR_altivec_vselti2 = 1839,
  CODE_FOR_altivec_vselkf2 = 1840,
  CODE_FOR_altivec_vseltf2 = 1841,
  CODE_FOR_altivec_vselv4si3 = 1842,
  CODE_FOR_altivec_vselv8hi3 = 1843,
  CODE_FOR_altivec_vselv16qi3 = 1844,
  CODE_FOR_altivec_vselv4sf3 = 1845,
  CODE_FOR_altivec_vselv2df3 = 1846,
  CODE_FOR_altivec_vselv2di3 = 1847,
  CODE_FOR_altivec_vselv1ti3 = 1848,
  CODE_FOR_altivec_vselti3 = 1849,
  CODE_FOR_altivec_vselkf3 = 1850,
  CODE_FOR_altivec_vseltf3 = 1851,
  CODE_FOR_altivec_vselv4si4 = 1852,
  CODE_FOR_altivec_vselv8hi4 = 1853,
  CODE_FOR_altivec_vselv16qi4 = 1854,
  CODE_FOR_altivec_vselv4sf4 = 1855,
  CODE_FOR_altivec_vselv2df4 = 1856,
  CODE_FOR_altivec_vselv2di4 = 1857,
  CODE_FOR_altivec_vselv1ti4 = 1858,
  CODE_FOR_altivec_vselti4 = 1859,
  CODE_FOR_altivec_vselkf4 = 1860,
  CODE_FOR_altivec_vseltf4 = 1861,
  CODE_FOR_mulv4si3_p8 = 1863,
  CODE_FOR_vsldb_v16qi = 1864,
  CODE_FOR_vsrdb_v16qi = 1865,
  CODE_FOR_vsldb_v8hi = 1866,
  CODE_FOR_vsrdb_v8hi = 1867,
  CODE_FOR_vsldb_v4si = 1868,
  CODE_FOR_vsrdb_v4si = 1869,
  CODE_FOR_vsldb_v2di = 1870,
  CODE_FOR_vsrdb_v2di = 1871,
  CODE_FOR_vsldb_v1ti = 1872,
  CODE_FOR_vsrdb_v1ti = 1873,
  CODE_FOR_vstrir_direct_v8hi = 1874,
  CODE_FOR_vstrir_direct_v16qi = 1875,
  CODE_FOR_vstrir_p_direct_v8hi = 1876,
  CODE_FOR_vstrir_p_direct_v16qi = 1877,
  CODE_FOR_vstril_direct_v8hi = 1878,
  CODE_FOR_vstril_direct_v16qi = 1879,
  CODE_FOR_vstril_p_direct_v8hi = 1880,
  CODE_FOR_vstril_p_direct_v16qi = 1881,
  CODE_FOR_altivec_vmsumuhm = 1883,
  CODE_FOR_altivec_vmsumubm = 1884,
  CODE_FOR_altivec_vmsumudm = 1885,
  CODE_FOR_altivec_vmsummhm = 1886,
  CODE_FOR_altivec_vmsummbm = 1887,
  CODE_FOR_altivec_vmsumshm = 1888,
  CODE_FOR_altivec_vmsumuhs = 1889,
  CODE_FOR_altivec_vmsumshs = 1890,
  CODE_FOR_umaxv4si3 = 1891,
  CODE_FOR_umaxv8hi3 = 1892,
  CODE_FOR_umaxv16qi3 = 1893,
  CODE_FOR_umaxv2di3 = 1894,
  CODE_FOR_smaxv4si3 = 1895,
  CODE_FOR_smaxv8hi3 = 1896,
  CODE_FOR_smaxv16qi3 = 1897,
  CODE_FOR_smaxv2di3 = 1898,
  CODE_FOR_uminv4si3 = 1900,
  CODE_FOR_uminv8hi3 = 1901,
  CODE_FOR_uminv16qi3 = 1902,
  CODE_FOR_uminv2di3 = 1903,
  CODE_FOR_sminv4si3 = 1904,
  CODE_FOR_sminv8hi3 = 1905,
  CODE_FOR_sminv16qi3 = 1906,
  CODE_FOR_sminv2di3 = 1907,
  CODE_FOR_altivec_vmhaddshs = 1909,
  CODE_FOR_altivec_vmhraddshs = 1910,
  CODE_FOR_fmav8hi4 = 1911,
  CODE_FOR_altivec_vmrghb_direct_be = 1912,
  CODE_FOR_altivec_vmrghb_direct_le = 1913,
  CODE_FOR_altivec_vmrghh_direct_be = 1914,
  CODE_FOR_altivec_vmrghh_direct_le = 1915,
  CODE_FOR_altivec_vmrghw_direct_v4sf_be = 1916,
  CODE_FOR_altivec_vmrghw_direct_v4si_be = 1917,
  CODE_FOR_altivec_vmrghw_direct_v4sf_le = 1918,
  CODE_FOR_altivec_vmrghw_direct_v4si_le = 1919,
  CODE_FOR_altivec_vmrglb_direct_be = 1921,
  CODE_FOR_altivec_vmrglb_direct_le = 1922,
  CODE_FOR_altivec_vmrglh_direct_be = 1923,
  CODE_FOR_altivec_vmrglh_direct_le = 1924,
  CODE_FOR_altivec_vmrglw_direct_v4sf_be = 1925,
  CODE_FOR_altivec_vmrglw_direct_v4si_be = 1926,
  CODE_FOR_altivec_vmrglw_direct_v4sf_le = 1927,
  CODE_FOR_altivec_vmrglw_direct_v4si_le = 1928,
  CODE_FOR_p8_vmrgew_v4sf = 1930,
  CODE_FOR_p8_vmrgew_v4si = 1931,
  CODE_FOR_p8_vmrgow_v4sf = 1932,
  CODE_FOR_p8_vmrgow_v4si = 1933,
  CODE_FOR_p8_vmrgew_v4sf_direct = 1934,
  CODE_FOR_p8_vmrgew_v4si_direct = 1935,
  CODE_FOR_p8_vmrgow_v4sf_direct = 1936,
  CODE_FOR_p8_vmrgow_v4si_direct = 1937,
  CODE_FOR_altivec_vmuleub = 1938,
  CODE_FOR_altivec_vmuloub = 1939,
  CODE_FOR_altivec_vmulesb = 1940,
  CODE_FOR_altivec_vmulosb = 1941,
  CODE_FOR_altivec_vmuleuh = 1942,
  CODE_FOR_altivec_vmulouh = 1943,
  CODE_FOR_altivec_vmulesh = 1944,
  CODE_FOR_altivec_vmulosh = 1945,
  CODE_FOR_altivec_vmuleuw = 1946,
  CODE_FOR_altivec_vmuleud = 1947,
  CODE_FOR_altivec_vmulouw = 1948,
  CODE_FOR_altivec_vmuloud = 1949,
  CODE_FOR_altivec_vmulesw = 1950,
  CODE_FOR_altivec_vmulesd = 1951,
  CODE_FOR_altivec_vmulosw = 1952,
  CODE_FOR_altivec_vmulosd = 1953,
  CODE_FOR_altivec_vpkpx = 1954,
  CODE_FOR_altivec_vpksdss = 1955,
  CODE_FOR_altivec_vpkswss = 1956,
  CODE_FOR_altivec_vpkshss = 1957,
  CODE_FOR_altivec_vpksdus = 1958,
  CODE_FOR_altivec_vpkswus = 1959,
  CODE_FOR_altivec_vpkshus = 1960,
  CODE_FOR_altivec_vpkudus = 1961,
  CODE_FOR_altivec_vpkuwus = 1962,
  CODE_FOR_altivec_vpkuhus = 1963,
  CODE_FOR_altivec_vpkudum = 1964,
  CODE_FOR_altivec_vpkuwum = 1965,
  CODE_FOR_altivec_vpkuhum = 1966,
  CODE_FOR_altivec_vpkudum_direct = 1967,
  CODE_FOR_altivec_vpkuwum_direct = 1968,
  CODE_FOR_altivec_vpkuhum_direct = 1969,
  CODE_FOR_altivec_vrlw = 1970,
  CODE_FOR_altivec_vrlh = 1971,
  CODE_FOR_altivec_vrlb = 1972,
  CODE_FOR_altivec_vrld = 1973,
  CODE_FOR_altivec_vrlq = 1974,
  CODE_FOR_altivec_vrldmi = 1975,
  CODE_FOR_altivec_vrlwmi = 1976,
  CODE_FOR_altivec_vrlqmi_inst = 1977,
  CODE_FOR_altivec_vrldnm = 1978,
  CODE_FOR_altivec_vrlwnm = 1979,
  CODE_FOR_altivec_vrlqnm_inst = 1980,
  CODE_FOR_altivec_vsl = 1981,
  CODE_FOR_altivec_vslo = 1982,
  CODE_FOR_vslv = 1983,
  CODE_FOR_vsrv = 1984,
  CODE_FOR_altivec_vslq_v1ti = 1989,
  CODE_FOR_altivec_vslq_ti = 1990,
  CODE_FOR_altivec_vsrq_v1ti = 1995,
  CODE_FOR_altivec_vsrq_ti = 1996,
  CODE_FOR_altivec_vsraq = 2001,
  CODE_FOR_altivec_vsr = 2002,
  CODE_FOR_altivec_vsro = 2003,
  CODE_FOR_altivec_vsum4ubs = 2012,
  CODE_FOR_altivec_vsum4shs = 2013,
  CODE_FOR_altivec_vsum4sbs = 2014,
  CODE_FOR_altivec_vsum2sws_direct = 2015,
  CODE_FOR_altivec_vsumsws_direct = 2016,
  CODE_FOR_altivec_vspltb_direct = 2018,
  CODE_FOR_altivec_vsplth_direct = 2020,
  CODE_FOR_altivec_vspltw_direct = 2022,
  CODE_FOR_altivec_vspltisw = 2024,
  CODE_FOR_altivec_vspltish = 2025,
  CODE_FOR_altivec_vspltisb = 2026,
  CODE_FOR_altivec_vperm_v4si_direct = 2028,
  CODE_FOR_altivec_vperm_v8hi_direct = 2029,
  CODE_FOR_altivec_vperm_v16qi_direct = 2030,
  CODE_FOR_altivec_vperm_v4sf_direct = 2031,
  CODE_FOR_altivec_vperm_v2df_direct = 2032,
  CODE_FOR_altivec_vperm_v2di_direct = 2033,
  CODE_FOR_altivec_vperm_v1ti_direct = 2034,
  CODE_FOR_altivec_vperm_ti_direct = 2035,
  CODE_FOR_altivec_vperm_kf_direct = 2036,
  CODE_FOR_altivec_vperm_tf_direct = 2037,
  CODE_FOR_altivec_vperm_v8hiv16qi = 2038,
  CODE_FOR_altivec_vrfip = 2059,
  CODE_FOR_altivec_vrfin = 2060,
  CODE_FOR_altivec_vcfux = 2062,
  CODE_FOR_altivec_vcfsx = 2063,
  CODE_FOR_altivec_vctuxs = 2064,
  CODE_FOR_altivec_vctsxs = 2065,
  CODE_FOR_altivec_vlogefp = 2066,
  CODE_FOR_altivec_vexptefp = 2067,
  CODE_FOR_altivec_vrefp = 2069,
  CODE_FOR_altivec_vsldoi_v4si = 2070,
  CODE_FOR_altivec_vsldoi_v8hi = 2071,
  CODE_FOR_altivec_vsldoi_v16qi = 2072,
  CODE_FOR_altivec_vsldoi_v4sf = 2073,
  CODE_FOR_altivec_vsldoi_v2df = 2074,
  CODE_FOR_altivec_vsldoi_v2di = 2075,
  CODE_FOR_altivec_vsldoi_v1ti = 2076,
  CODE_FOR_altivec_vsldoi_ti = 2077,
  CODE_FOR_altivec_vsldoi_kf = 2078,
  CODE_FOR_altivec_vsldoi_tf = 2079,
  CODE_FOR_altivec_vupkhsw = 2080,
  CODE_FOR_altivec_vupkhsh = 2081,
  CODE_FOR_altivec_vupkhsb = 2082,
  CODE_FOR_altivec_vupkhsw_direct = 2083,
  CODE_FOR_altivec_vupkhsh_direct = 2084,
  CODE_FOR_altivec_vupkhsb_direct = 2085,
  CODE_FOR_altivec_vupklsw = 2086,
  CODE_FOR_altivec_vupklsh = 2087,
  CODE_FOR_altivec_vupklsb = 2088,
  CODE_FOR_altivec_vupkhpx = 2092,
  CODE_FOR_altivec_vupklpx = 2093,
  CODE_FOR_altivec_vcmpequw_p = 2094,
  CODE_FOR_altivec_vcmpequh_p = 2095,
  CODE_FOR_altivec_vcmpequb_p = 2096,
  CODE_FOR_altivec_vcmpequd_p = 2097,
  CODE_FOR_altivec_vcmpequt_p = 2098,
  CODE_FOR_altivec_vcmpbfp_p = 2112,
  CODE_FOR_altivec_mtvscr = 2113,
  CODE_FOR_altivec_mfvscr = 2114,
  CODE_FOR_altivec_dssall = 2115,
  CODE_FOR_altivec_dss = 2116,
  CODE_FOR_altivec_dst = 2117,
  CODE_FOR_altivec_dstt = 2118,
  CODE_FOR_altivec_dstst = 2119,
  CODE_FOR_altivec_dststt = 2120,
  CODE_FOR_altivec_lvsl_reg_si = 2121,
  CODE_FOR_altivec_lvsl_reg_di = 2122,
  CODE_FOR_altivec_lvsl_direct = 2123,
  CODE_FOR_altivec_lvsr_reg_si = 2124,
  CODE_FOR_altivec_lvsr_reg_di = 2125,
  CODE_FOR_altivec_lvsr_direct = 2126,
  CODE_FOR_altivec_lvewx = 2127,
  CODE_FOR_altivec_lvehx = 2128,
  CODE_FOR_altivec_lvebx = 2129,
  CODE_FOR_altivec_lvxl_v4si = 2131,
  CODE_FOR_altivec_lvxl_v8hi = 2132,
  CODE_FOR_altivec_lvxl_v16qi = 2133,
  CODE_FOR_altivec_lvxl_v4sf = 2134,
  CODE_FOR_altivec_lvxl_v2df = 2135,
  CODE_FOR_altivec_lvxl_v2di = 2136,
  CODE_FOR_altivec_lvxl_v1ti = 2137,
  CODE_FOR_altivec_lvxl_kf = 2138,
  CODE_FOR_altivec_lvxl_tf = 2139,
  CODE_FOR_altivec_lvx_v4si_internal = 2140,
  CODE_FOR_altivec_lvx_v8hi_internal = 2141,
  CODE_FOR_altivec_lvx_v16qi_internal = 2142,
  CODE_FOR_altivec_lvx_v4sf_internal = 2143,
  CODE_FOR_altivec_lvx_v2df_internal = 2144,
  CODE_FOR_altivec_lvx_v2di_internal = 2145,
  CODE_FOR_altivec_lvx_v1ti_internal = 2146,
  CODE_FOR_altivec_lvx_kf_internal = 2147,
  CODE_FOR_altivec_lvx_tf_internal = 2148,
  CODE_FOR_altivec_lvx_v4si_2op_si = 2149,
  CODE_FOR_altivec_lvx_v4si_2op_di = 2150,
  CODE_FOR_altivec_lvx_v8hi_2op_si = 2151,
  CODE_FOR_altivec_lvx_v8hi_2op_di = 2152,
  CODE_FOR_altivec_lvx_v16qi_2op_si = 2153,
  CODE_FOR_altivec_lvx_v16qi_2op_di = 2154,
  CODE_FOR_altivec_lvx_v4sf_2op_si = 2155,
  CODE_FOR_altivec_lvx_v4sf_2op_di = 2156,
  CODE_FOR_altivec_lvx_v2df_2op_si = 2157,
  CODE_FOR_altivec_lvx_v2df_2op_di = 2158,
  CODE_FOR_altivec_lvx_v2di_2op_si = 2159,
  CODE_FOR_altivec_lvx_v2di_2op_di = 2160,
  CODE_FOR_altivec_lvx_v1ti_2op_si = 2161,
  CODE_FOR_altivec_lvx_v1ti_2op_di = 2162,
  CODE_FOR_altivec_lvx_kf_2op_si = 2163,
  CODE_FOR_altivec_lvx_kf_2op_di = 2164,
  CODE_FOR_altivec_lvx_tf_2op_si = 2165,
  CODE_FOR_altivec_lvx_tf_2op_di = 2166,
  CODE_FOR_altivec_lvx_v4si_1op_si = 2167,
  CODE_FOR_altivec_lvx_v4si_1op_di = 2168,
  CODE_FOR_altivec_lvx_v8hi_1op_si = 2169,
  CODE_FOR_altivec_lvx_v8hi_1op_di = 2170,
  CODE_FOR_altivec_lvx_v16qi_1op_si = 2171,
  CODE_FOR_altivec_lvx_v16qi_1op_di = 2172,
  CODE_FOR_altivec_lvx_v4sf_1op_si = 2173,
  CODE_FOR_altivec_lvx_v4sf_1op_di = 2174,
  CODE_FOR_altivec_lvx_v2df_1op_si = 2175,
  CODE_FOR_altivec_lvx_v2df_1op_di = 2176,
  CODE_FOR_altivec_lvx_v2di_1op_si = 2177,
  CODE_FOR_altivec_lvx_v2di_1op_di = 2178,
  CODE_FOR_altivec_lvx_v1ti_1op_si = 2179,
  CODE_FOR_altivec_lvx_v1ti_1op_di = 2180,
  CODE_FOR_altivec_lvx_kf_1op_si = 2181,
  CODE_FOR_altivec_lvx_kf_1op_di = 2182,
  CODE_FOR_altivec_lvx_tf_1op_si = 2183,
  CODE_FOR_altivec_lvx_tf_1op_di = 2184,
  CODE_FOR_altivec_stvx_v4si_internal = 2185,
  CODE_FOR_altivec_stvx_v8hi_internal = 2186,
  CODE_FOR_altivec_stvx_v16qi_internal = 2187,
  CODE_FOR_altivec_stvx_v4sf_internal = 2188,
  CODE_FOR_altivec_stvx_v2df_internal = 2189,
  CODE_FOR_altivec_stvx_v2di_internal = 2190,
  CODE_FOR_altivec_stvx_v1ti_internal = 2191,
  CODE_FOR_altivec_stvx_kf_internal = 2192,
  CODE_FOR_altivec_stvx_tf_internal = 2193,
  CODE_FOR_altivec_stvx_v4si_2op_si = 2194,
  CODE_FOR_altivec_stvx_v4si_2op_di = 2195,
  CODE_FOR_altivec_stvx_v8hi_2op_si = 2196,
  CODE_FOR_altivec_stvx_v8hi_2op_di = 2197,
  CODE_FOR_altivec_stvx_v16qi_2op_si = 2198,
  CODE_FOR_altivec_stvx_v16qi_2op_di = 2199,
  CODE_FOR_altivec_stvx_v4sf_2op_si = 2200,
  CODE_FOR_altivec_stvx_v4sf_2op_di = 2201,
  CODE_FOR_altivec_stvx_v2df_2op_si = 2202,
  CODE_FOR_altivec_stvx_v2df_2op_di = 2203,
  CODE_FOR_altivec_stvx_v2di_2op_si = 2204,
  CODE_FOR_altivec_stvx_v2di_2op_di = 2205,
  CODE_FOR_altivec_stvx_v1ti_2op_si = 2206,
  CODE_FOR_altivec_stvx_v1ti_2op_di = 2207,
  CODE_FOR_altivec_stvx_kf_2op_si = 2208,
  CODE_FOR_altivec_stvx_kf_2op_di = 2209,
  CODE_FOR_altivec_stvx_tf_2op_si = 2210,
  CODE_FOR_altivec_stvx_tf_2op_di = 2211,
  CODE_FOR_altivec_stvx_v4si_1op_si = 2212,
  CODE_FOR_altivec_stvx_v4si_1op_di = 2213,
  CODE_FOR_altivec_stvx_v8hi_1op_si = 2214,
  CODE_FOR_altivec_stvx_v8hi_1op_di = 2215,
  CODE_FOR_altivec_stvx_v16qi_1op_si = 2216,
  CODE_FOR_altivec_stvx_v16qi_1op_di = 2217,
  CODE_FOR_altivec_stvx_v4sf_1op_si = 2218,
  CODE_FOR_altivec_stvx_v4sf_1op_di = 2219,
  CODE_FOR_altivec_stvx_v2df_1op_si = 2220,
  CODE_FOR_altivec_stvx_v2df_1op_di = 2221,
  CODE_FOR_altivec_stvx_v2di_1op_si = 2222,
  CODE_FOR_altivec_stvx_v2di_1op_di = 2223,
  CODE_FOR_altivec_stvx_v1ti_1op_si = 2224,
  CODE_FOR_altivec_stvx_v1ti_1op_di = 2225,
  CODE_FOR_altivec_stvx_kf_1op_si = 2226,
  CODE_FOR_altivec_stvx_kf_1op_di = 2227,
  CODE_FOR_altivec_stvx_tf_1op_si = 2228,
  CODE_FOR_altivec_stvx_tf_1op_di = 2229,
  CODE_FOR_altivec_stvxl_v4si = 2230,
  CODE_FOR_altivec_stvxl_v8hi = 2231,
  CODE_FOR_altivec_stvxl_v16qi = 2232,
  CODE_FOR_altivec_stvxl_v4sf = 2233,
  CODE_FOR_altivec_stvxl_v2df = 2234,
  CODE_FOR_altivec_stvxl_v2di = 2235,
  CODE_FOR_altivec_stvxl_v1ti = 2236,
  CODE_FOR_altivec_stvxl_kf = 2237,
  CODE_FOR_altivec_stvxl_tf = 2238,
  CODE_FOR_altivec_stvewx = 2239,
  CODE_FOR_altivec_stvehx = 2240,
  CODE_FOR_altivec_stvebx = 2241,
  CODE_FOR_vperm_v8hiv4si = 2245,
  CODE_FOR_vperm_v16qiv8hi = 2246,
  CODE_FOR_altivec_lvlx = 2247,
  CODE_FOR_altivec_lvlxl = 2248,
  CODE_FOR_altivec_lvrx = 2249,
  CODE_FOR_altivec_lvrxl = 2250,
  CODE_FOR_altivec_stvlx = 2251,
  CODE_FOR_altivec_stvlxl = 2252,
  CODE_FOR_altivec_stvrx = 2253,
  CODE_FOR_altivec_stvrxl = 2254,
  CODE_FOR_uabdv4si3 = 2259,
  CODE_FOR_uabdv8hi3 = 2260,
  CODE_FOR_uabdv16qi3 = 2261,
  CODE_FOR_rs6000_vprtybv8hi2 = 2270,
  CODE_FOR_rs6000_vprtybv4si2 = 2271,
  CODE_FOR_rs6000_vprtybv2di2 = 2272,
  CODE_FOR_rs6000_vprtybv1ti2 = 2273,
  CODE_FOR_rs6000_vprtybti2 = 2274,
  CODE_FOR_p8v_vgbbd = 2275,
  CODE_FOR_addv1ti3 = 2276,
  CODE_FOR_altivec_vaddcuq = 2277,
  CODE_FOR_subv1ti3 = 2278,
  CODE_FOR_altivec_vsubcuq = 2279,
  CODE_FOR_altivec_vaddeuqm = 2280,
  CODE_FOR_altivec_vaddecuq = 2281,
  CODE_FOR_altivec_vsubeuqm = 2282,
  CODE_FOR_altivec_vsubecuq = 2283,
  CODE_FOR_altivec_vbpermq = 2284,
  CODE_FOR_altivec_vbpermq2 = 2285,
  CODE_FOR_altivec_vbpermd = 2286,
  CODE_FOR_bcdadd_v1ti = 2287,
  CODE_FOR_bcdsub_v1ti = 2288,
  CODE_FOR_bcdadd_v16qi = 2289,
  CODE_FOR_bcdsub_v16qi = 2290,
  CODE_FOR_vcfuged = 2299,
  CODE_FOR_vclzdm = 2300,
  CODE_FOR_vctzdm = 2301,
  CODE_FOR_vpdepd = 2302,
  CODE_FOR_vpextd = 2303,
  CODE_FOR_vgnb = 2304,
  CODE_FOR_vclrlb = 2305,
  CODE_FOR_vclrrb = 2306,
  CODE_FOR_bcdshift_v16qi = 2309,
  CODE_FOR_mma_xxmfacc = 2316,
  CODE_FOR_mma_xxmtacc = 2317,
  CODE_FOR_mma_xxsetaccz = 2318,
  CODE_FOR_mma_xvi4ger8 = 2319,
  CODE_FOR_mma_xvi8ger4 = 2320,
  CODE_FOR_mma_xvi16ger2 = 2321,
  CODE_FOR_mma_xvi16ger2s = 2322,
  CODE_FOR_mma_xvf16ger2 = 2323,
  CODE_FOR_mma_xvbf16ger2 = 2324,
  CODE_FOR_mma_xvf32ger = 2325,
  CODE_FOR_mma_xvi4ger8pp = 2326,
  CODE_FOR_mma_xvi8ger4pp = 2327,
  CODE_FOR_mma_xvi8ger4spp = 2328,
  CODE_FOR_mma_xvi16ger2pp = 2329,
  CODE_FOR_mma_xvi16ger2spp = 2330,
  CODE_FOR_mma_xvf16ger2pp = 2331,
  CODE_FOR_mma_xvf16ger2pn = 2332,
  CODE_FOR_mma_xvf16ger2np = 2333,
  CODE_FOR_mma_xvf16ger2nn = 2334,
  CODE_FOR_mma_xvbf16ger2pp = 2335,
  CODE_FOR_mma_xvbf16ger2pn = 2336,
  CODE_FOR_mma_xvbf16ger2np = 2337,
  CODE_FOR_mma_xvbf16ger2nn = 2338,
  CODE_FOR_mma_xvf32gerpp = 2339,
  CODE_FOR_mma_xvf32gerpn = 2340,
  CODE_FOR_mma_xvf32gernp = 2341,
  CODE_FOR_mma_xvf32gernn = 2342,
  CODE_FOR_mma_xvf64ger = 2343,
  CODE_FOR_mma_xvf64gerpp = 2344,
  CODE_FOR_mma_xvf64gerpn = 2345,
  CODE_FOR_mma_xvf64gernp = 2346,
  CODE_FOR_mma_xvf64gernn = 2347,
  CODE_FOR_mma_pmxvi4ger8 = 2348,
  CODE_FOR_mma_pmxvi4ger8pp = 2349,
  CODE_FOR_mma_pmxvi16ger2 = 2350,
  CODE_FOR_mma_pmxvi16ger2s = 2351,
  CODE_FOR_mma_pmxvf16ger2 = 2352,
  CODE_FOR_mma_pmxvbf16ger2 = 2353,
  CODE_FOR_mma_pmxvi16ger2pp = 2354,
  CODE_FOR_mma_pmxvi16ger2spp = 2355,
  CODE_FOR_mma_pmxvf16ger2pp = 2356,
  CODE_FOR_mma_pmxvf16ger2pn = 2357,
  CODE_FOR_mma_pmxvf16ger2np = 2358,
  CODE_FOR_mma_pmxvf16ger2nn = 2359,
  CODE_FOR_mma_pmxvbf16ger2pp = 2360,
  CODE_FOR_mma_pmxvbf16ger2pn = 2361,
  CODE_FOR_mma_pmxvbf16ger2np = 2362,
  CODE_FOR_mma_pmxvbf16ger2nn = 2363,
  CODE_FOR_mma_pmxvf32ger = 2364,
  CODE_FOR_mma_pmxvf32gerpp = 2365,
  CODE_FOR_mma_pmxvf32gerpn = 2366,
  CODE_FOR_mma_pmxvf32gernp = 2367,
  CODE_FOR_mma_pmxvf32gernn = 2368,
  CODE_FOR_mma_pmxvf64ger = 2369,
  CODE_FOR_mma_pmxvf64gerpp = 2370,
  CODE_FOR_mma_pmxvf64gerpn = 2371,
  CODE_FOR_mma_pmxvf64gernp = 2372,
  CODE_FOR_mma_pmxvf64gernn = 2373,
  CODE_FOR_mma_pmxvi8ger4 = 2374,
  CODE_FOR_mma_pmxvi8ger4pp = 2375,
  CODE_FOR_mma_pmxvi8ger4spp = 2376,
  CODE_FOR_movsd_store = 2377,
  CODE_FOR_movsd_load = 2378,
  CODE_FOR_extendsddd2 = 2379,
  CODE_FOR_truncddsd2 = 2380,
  CODE_FOR_negdd2 = 2381,
  CODE_FOR_absdd2 = 2382,
  CODE_FOR_negtd2 = 2384,
  CODE_FOR_abstd2 = 2385,
  CODE_FOR_extendddtd2 = 2387,
  CODE_FOR_trunctddd2 = 2388,
  CODE_FOR_trunctdsd2 = 2389,
  CODE_FOR_adddd3 = 2390,
  CODE_FOR_addtd3 = 2391,
  CODE_FOR_subdd3 = 2392,
  CODE_FOR_subtd3 = 2393,
  CODE_FOR_muldd3 = 2394,
  CODE_FOR_multd3 = 2395,
  CODE_FOR_divdd3 = 2396,
  CODE_FOR_divtd3 = 2397,
  CODE_FOR_floatdidd2 = 2400,
  CODE_FOR_floatditd2 = 2401,
  CODE_FOR_floattitd2 = 2402,
  CODE_FOR_ftruncdd2 = 2403,
  CODE_FOR_ftrunctd2 = 2404,
  CODE_FOR_fixdddi2 = 2405,
  CODE_FOR_fixtddi2 = 2406,
  CODE_FOR_fixtdti2 = 2407,
  CODE_FOR_dfp_ddedpd_dd = 2408,
  CODE_FOR_dfp_ddedpd_td = 2409,
  CODE_FOR_dfp_denbcd_dd = 2410,
  CODE_FOR_dfp_denbcd_td = 2411,
  CODE_FOR_dfp_denbcd_v16qi_inst = 2412,
  CODE_FOR_dfp_dxex_dd = 2413,
  CODE_FOR_dfp_dxex_td = 2414,
  CODE_FOR_dfp_diex_dd = 2415,
  CODE_FOR_dfp_diex_td = 2416,
  CODE_FOR_dfp_dscli_dd = 2419,
  CODE_FOR_dfp_dscli_td = 2420,
  CODE_FOR_dfp_dscri_dd = 2421,
  CODE_FOR_dfp_dscri_td = 2422,
  CODE_FOR_dfp_dqua_dd = 2423,
  CODE_FOR_dfp_dqua_td = 2424,
  CODE_FOR_dfp_dquai_dd = 2425,
  CODE_FOR_dfp_dquai_td = 2426,
  CODE_FOR_crypto_vcipher_v16qi = 2427,
  CODE_FOR_crypto_vncipher_v16qi = 2428,
  CODE_FOR_crypto_vcipherlast_v16qi = 2429,
  CODE_FOR_crypto_vncipherlast_v16qi = 2430,
  CODE_FOR_crypto_vcipher_v2di = 2431,
  CODE_FOR_crypto_vncipher_v2di = 2432,
  CODE_FOR_crypto_vcipherlast_v2di = 2433,
  CODE_FOR_crypto_vncipherlast_v2di = 2434,
  CODE_FOR_crypto_vpmsumb = 2435,
  CODE_FOR_crypto_vpmsumh = 2436,
  CODE_FOR_crypto_vpmsumw = 2437,
  CODE_FOR_crypto_vpmsumd = 2438,
  CODE_FOR_crypto_vpermxor_v16qi = 2439,
  CODE_FOR_crypto_vpermxor_v8hi = 2440,
  CODE_FOR_crypto_vpermxor_v4si = 2441,
  CODE_FOR_crypto_vpermxor_v2di = 2442,
  CODE_FOR_crypto_vsbox_v16qi = 2443,
  CODE_FOR_crypto_vsbox_v2di = 2444,
  CODE_FOR_crypto_vshasigmaw = 2445,
  CODE_FOR_crypto_vshasigmad = 2446,
  CODE_FOR_htm_mfspr_si = 2459,
  CODE_FOR_htm_mfspr_di = 2460,
  CODE_FOR_htm_mtspr_si = 2461,
  CODE_FOR_htm_mtspr_di = 2462,
  CODE_FOR_pcrel_opt_ld_addr = 3296,
  CODE_FOR_pcrel_opt_ld_addr_same_reg = 3297,
  CODE_FOR_extendhisi2 = 3358,
  CODE_FOR_extendhidi2 = 3359,
  CODE_FOR_strlensi = 3360,
  CODE_FOR_addsi3 = 3361,
  CODE_FOR_adddi3 = 3362,
  CODE_FOR_addsi3_carry_in = 3363,
  CODE_FOR_adddi3_carry_in = 3364,
  CODE_FOR_one_cmplsi2 = 3365,
  CODE_FOR_one_cmpldi2 = 3366,
  CODE_FOR_subsi3 = 3367,
  CODE_FOR_subdi3 = 3368,
  CODE_FOR_subfsi3_carry_in = 3369,
  CODE_FOR_subfdi3_carry_in = 3370,
  CODE_FOR_ctzsi2 = 3371,
  CODE_FOR_ctzdi2 = 3372,
  CODE_FOR_ffssi2 = 3373,
  CODE_FOR_ffsdi2 = 3374,
  CODE_FOR_popcountsi2 = 3375,
  CODE_FOR_popcountdi2 = 3376,
  CODE_FOR_paritysi2 = 3377,
  CODE_FOR_paritydi2 = 3378,
  CODE_FOR_bswaphi2 = 3379,
  CODE_FOR_bswapsi2 = 3380,
  CODE_FOR_bswapdi2 = 3381,
  CODE_FOR_smulsi3_highpart = 3382,
  CODE_FOR_umulsi3_highpart = 3383,
  CODE_FOR_smuldi3_highpart = 3384,
  CODE_FOR_umuldi3_highpart = 3385,
  CODE_FOR_mulsidi3 = 3386,
  CODE_FOR_umulsidi3 = 3387,
  CODE_FOR_mulditi3 = 3388,
  CODE_FOR_umulditi3 = 3389,
  CODE_FOR_umaddditi4 = 3390,
  CODE_FOR_divsi3 = 3391,
  CODE_FOR_divdi3 = 3392,
  CODE_FOR_modsi3 = 3393,
  CODE_FOR_moddi3 = 3394,
  CODE_FOR_umodsi3 = 3395,
  CODE_FOR_umoddi3 = 3396,
  CODE_FOR_andsi3 = 3397,
  CODE_FOR_anddi3 = 3398,
  CODE_FOR_iorsi3 = 3399,
  CODE_FOR_xorsi3 = 3400,
  CODE_FOR_iordi3 = 3401,
  CODE_FOR_xordi3 = 3402,
  CODE_FOR_recipsf3 = 3403,
  CODE_FOR_recipdf3 = 3404,
  CODE_FOR_recipv4sf3 = 3405,
  CODE_FOR_recipv2df3 = 3406,
  CODE_FOR_rsqrtsf2 = 3407,
  CODE_FOR_rsqrtdf2 = 3408,
  CODE_FOR_rsqrtv4sf2 = 3409,
  CODE_FOR_rsqrtv2df2 = 3410,
  CODE_FOR_abssf2 = 3411,
  CODE_FOR_absdf2 = 3412,
  CODE_FOR_negsf2 = 3413,
  CODE_FOR_negdf2 = 3414,
  CODE_FOR_addsf3 = 3415,
  CODE_FOR_adddf3 = 3416,
  CODE_FOR_subsf3 = 3417,
  CODE_FOR_subdf3 = 3418,
  CODE_FOR_mulsf3 = 3419,
  CODE_FOR_muldf3 = 3420,
  CODE_FOR_divsf3 = 3421,
  CODE_FOR_divdf3 = 3422,
  CODE_FOR_sqrtsf2 = 3423,
  CODE_FOR_sqrtdf2 = 3424,
  CODE_FOR_fmodsf3 = 3425,
  CODE_FOR_fmoddf3 = 3426,
  CODE_FOR_remaindersf3 = 3427,
  CODE_FOR_remainderdf3 = 3428,
  CODE_FOR_extendsfdf2 = 3429,
  CODE_FOR_truncdfsf2 = 3430,
  CODE_FOR_signbitkf2 = 3431,
  CODE_FOR_signbitif2 = 3432,
  CODE_FOR_signbittf2 = 3433,
  CODE_FOR_copysignsf3 = 3434,
  CODE_FOR_copysigndf3 = 3435,
  CODE_FOR_sminsf3 = 3436,
  CODE_FOR_smaxsf3 = 3437,
  CODE_FOR_smindf3 = 3438,
  CODE_FOR_smaxdf3 = 3439,
  CODE_FOR_movsicc = 3440,
  CODE_FOR_movdicc = 3441,
  CODE_FOR_movsfcc = 3442,
  CODE_FOR_movdfcc = 3443,
  CODE_FOR_movkfcc = 3444,
  CODE_FOR_movtfcc = 3445,
  CODE_FOR_floatsidf2 = 3446,
  CODE_FOR_floatunssisf2 = 3447,
  CODE_FOR_floatunssidf2 = 3448,
  CODE_FOR_floatqisf2 = 3449,
  CODE_FOR_floathisf2 = 3450,
  CODE_FOR_floatqidf2 = 3451,
  CODE_FOR_floathidf2 = 3452,
  CODE_FOR_floatunsqisf2 = 3453,
  CODE_FOR_floatunshisf2 = 3454,
  CODE_FOR_floatunsqidf2 = 3455,
  CODE_FOR_floatunshidf2 = 3456,
  CODE_FOR_fix_truncsfsi2 = 3457,
  CODE_FOR_fix_truncdfsi2 = 3458,
  CODE_FOR_fix_truncsfdi2 = 3459,
  CODE_FOR_fix_truncdfdi2 = 3460,
  CODE_FOR_fixuns_truncsfsi2 = 3461,
  CODE_FOR_fixuns_truncdfsi2 = 3462,
  CODE_FOR_rs6000_set_fpscr_rn = 3463,
  CODE_FOR_rs6000_set_fpscr_drn = 3464,
  CODE_FOR_lrintsfsi2 = 3465,
  CODE_FOR_lrintdfsi2 = 3466,
  CODE_FOR_lroundsfdi2 = 3467,
  CODE_FOR_lrounddfdi2 = 3468,
  CODE_FOR_floatsisf2 = 3469,
  CODE_FOR_floatunsdidf2 = 3470,
  CODE_FOR_floatdisf2 = 3471,
  CODE_FOR_floatdisf2_internal2 = 3472,
  CODE_FOR_floatunsdisf2 = 3473,
  CODE_FOR_fegetroundsi = 3474,
  CODE_FOR_feclearexceptsi = 3475,
  CODE_FOR_feraiseexceptsi = 3476,
  CODE_FOR_addti3 = 3477,
  CODE_FOR_subti3 = 3478,
  CODE_FOR_andti3 = 3479,
  CODE_FOR_andpti3 = 3480,
  CODE_FOR_andv16qi3 = 3481,
  CODE_FOR_andv8hi3 = 3482,
  CODE_FOR_andv4si3 = 3483,
  CODE_FOR_andv4sf3 = 3484,
  CODE_FOR_andv2di3 = 3485,
  CODE_FOR_andv2df3 = 3486,
  CODE_FOR_andv1ti3 = 3487,
  CODE_FOR_iorti3 = 3488,
  CODE_FOR_iorpti3 = 3489,
  CODE_FOR_iorv16qi3 = 3490,
  CODE_FOR_iorv8hi3 = 3491,
  CODE_FOR_iorv4si3 = 3492,
  CODE_FOR_iorv4sf3 = 3493,
  CODE_FOR_iorv2di3 = 3494,
  CODE_FOR_iorv2df3 = 3495,
  CODE_FOR_iorv1ti3 = 3496,
  CODE_FOR_xorti3 = 3497,
  CODE_FOR_xorpti3 = 3498,
  CODE_FOR_xorv16qi3 = 3499,
  CODE_FOR_xorv8hi3 = 3500,
  CODE_FOR_xorv4si3 = 3501,
  CODE_FOR_xorv4sf3 = 3502,
  CODE_FOR_xorv2di3 = 3503,
  CODE_FOR_xorv2df3 = 3504,
  CODE_FOR_xorv1ti3 = 3505,
  CODE_FOR_norti3 = 3506,
  CODE_FOR_norpti3 = 3507,
  CODE_FOR_norv16qi3 = 3508,
  CODE_FOR_norv8hi3 = 3509,
  CODE_FOR_norv4si3 = 3510,
  CODE_FOR_norv4sf3 = 3511,
  CODE_FOR_norv2di3 = 3512,
  CODE_FOR_norv2df3 = 3513,
  CODE_FOR_norv1ti3 = 3514,
  CODE_FOR_andnti3 = 3515,
  CODE_FOR_andnpti3 = 3516,
  CODE_FOR_andnv16qi3 = 3517,
  CODE_FOR_andnv8hi3 = 3518,
  CODE_FOR_andnv4si3 = 3519,
  CODE_FOR_andnv4sf3 = 3520,
  CODE_FOR_andnv2di3 = 3521,
  CODE_FOR_andnv2df3 = 3522,
  CODE_FOR_andnv1ti3 = 3523,
  CODE_FOR_eqvti3 = 3524,
  CODE_FOR_eqvpti3 = 3525,
  CODE_FOR_eqvv16qi3 = 3526,
  CODE_FOR_eqvv8hi3 = 3527,
  CODE_FOR_eqvv4si3 = 3528,
  CODE_FOR_eqvv4sf3 = 3529,
  CODE_FOR_eqvv2di3 = 3530,
  CODE_FOR_eqvv2df3 = 3531,
  CODE_FOR_eqvv1ti3 = 3532,
  CODE_FOR_nandti3 = 3533,
  CODE_FOR_nandpti3 = 3534,
  CODE_FOR_nandv16qi3 = 3535,
  CODE_FOR_nandv8hi3 = 3536,
  CODE_FOR_nandv4si3 = 3537,
  CODE_FOR_nandv4sf3 = 3538,
  CODE_FOR_nandv2di3 = 3539,
  CODE_FOR_nandv2df3 = 3540,
  CODE_FOR_nandv1ti3 = 3541,
  CODE_FOR_iornti3 = 3542,
  CODE_FOR_iornpti3 = 3543,
  CODE_FOR_iornv16qi3 = 3544,
  CODE_FOR_iornv8hi3 = 3545,
  CODE_FOR_iornv4si3 = 3546,
  CODE_FOR_iornv4sf3 = 3547,
  CODE_FOR_iornv2di3 = 3548,
  CODE_FOR_iornv2df3 = 3549,
  CODE_FOR_iornv1ti3 = 3550,
  CODE_FOR_movsi_got = 3551,
  CODE_FOR_movqi = 3552,
  CODE_FOR_movhi = 3553,
  CODE_FOR_movsi = 3554,
  CODE_FOR_movdi = 3555,
  CODE_FOR_movti = 3556,
  CODE_FOR_movpti = 3557,
  CODE_FOR_movcc = 3558,
  CODE_FOR_movsf = 3559,
  CODE_FOR_movsd = 3560,
  CODE_FOR_movdf = 3561,
  CODE_FOR_movdd = 3562,
  CODE_FOR_movtf = 3563,
  CODE_FOR_movif = 3564,
  CODE_FOR_movtd = 3565,
  CODE_FOR_extenddfkf2 = 3566,
  CODE_FOR_extenddfif2 = 3567,
  CODE_FOR_extenddftf2 = 3568,
  CODE_FOR_extendsfkf2 = 3569,
  CODE_FOR_extendsfif2 = 3570,
  CODE_FOR_extendsftf2 = 3571,
  CODE_FOR_trunckfdf2 = 3572,
  CODE_FOR_truncifdf2 = 3573,
  CODE_FOR_trunctfdf2 = 3574,
  CODE_FOR_trunckfsf2 = 3575,
  CODE_FOR_truncifsf2 = 3576,
  CODE_FOR_trunctfsf2 = 3577,
  CODE_FOR_floatsikf2 = 3578,
  CODE_FOR_floatsiif2 = 3579,
  CODE_FOR_floatsitf2 = 3580,
  CODE_FOR_fix_trunckfsi2 = 3581,
  CODE_FOR_fix_truncifsi2 = 3582,
  CODE_FOR_fix_trunctfsi2 = 3583,
  CODE_FOR_fix_truncifsi2_fprs = 3584,
  CODE_FOR_fix_trunctfsi2_fprs = 3585,
  CODE_FOR_fix_trunckfdi2 = 3586,
  CODE_FOR_fix_trunctfdi2 = 3587,
  CODE_FOR_fixuns_trunckfsi2 = 3588,
  CODE_FOR_fixuns_trunctfsi2 = 3589,
  CODE_FOR_fixuns_trunckfdi2 = 3590,
  CODE_FOR_fixuns_trunctfdi2 = 3591,
  CODE_FOR_floatdikf2 = 3592,
  CODE_FOR_floatditf2 = 3593,
  CODE_FOR_floatunsdikf2 = 3594,
  CODE_FOR_floatunsditf2 = 3595,
  CODE_FOR_floatunskf2 = 3596,
  CODE_FOR_floatunstf2 = 3597,
  CODE_FOR_negkf2 = 3598,
  CODE_FOR_negif2 = 3599,
  CODE_FOR_negtf2 = 3600,
  CODE_FOR_abskf2 = 3601,
  CODE_FOR_absif2 = 3602,
  CODE_FOR_abstf2 = 3603,
  CODE_FOR_absif2_internal = 3604,
  CODE_FOR_abstf2_internal = 3605,
  CODE_FOR_ieee_128bit_negative_zero = 3606,
  CODE_FOR_extendtfif2 = 3607,
  CODE_FOR_extendkftf2 = 3608,
  CODE_FOR_trunciftf2 = 3609,
  CODE_FOR_trunctfkf2 = 3610,
  CODE_FOR_truncifkf2 = 3611,
  CODE_FOR_extendkfif2 = 3612,
  CODE_FOR_reload_si_store = 3613,
  CODE_FOR_reload_di_store = 3614,
  CODE_FOR_reload_si_load = 3615,
  CODE_FOR_reload_di_load = 3616,
  CODE_FOR_reload_v16qi_si_store = 3617,
  CODE_FOR_reload_v8hi_si_store = 3618,
  CODE_FOR_reload_v4si_si_store = 3619,
  CODE_FOR_reload_v2di_si_store = 3620,
  CODE_FOR_reload_v4sf_si_store = 3621,
  CODE_FOR_reload_v2df_si_store = 3622,
  CODE_FOR_reload_v1ti_si_store = 3623,
  CODE_FOR_reload_sf_si_store = 3624,
  CODE_FOR_reload_sd_si_store = 3625,
  CODE_FOR_reload_si_si_store = 3626,
  CODE_FOR_reload_df_si_store = 3627,
  CODE_FOR_reload_dd_si_store = 3628,
  CODE_FOR_reload_di_si_store = 3629,
  CODE_FOR_reload_ti_si_store = 3630,
  CODE_FOR_reload_pti_si_store = 3631,
  CODE_FOR_reload_kf_si_store = 3632,
  CODE_FOR_reload_if_si_store = 3633,
  CODE_FOR_reload_tf_si_store = 3634,
  CODE_FOR_reload_oo_si_store = 3635,
  CODE_FOR_reload_xo_si_store = 3636,
  CODE_FOR_reload_v16qi_di_store = 3637,
  CODE_FOR_reload_v8hi_di_store = 3638,
  CODE_FOR_reload_v4si_di_store = 3639,
  CODE_FOR_reload_v2di_di_store = 3640,
  CODE_FOR_reload_v4sf_di_store = 3641,
  CODE_FOR_reload_v2df_di_store = 3642,
  CODE_FOR_reload_v1ti_di_store = 3643,
  CODE_FOR_reload_sf_di_store = 3644,
  CODE_FOR_reload_sd_di_store = 3645,
  CODE_FOR_reload_si_di_store = 3646,
  CODE_FOR_reload_df_di_store = 3647,
  CODE_FOR_reload_dd_di_store = 3648,
  CODE_FOR_reload_di_di_store = 3649,
  CODE_FOR_reload_ti_di_store = 3650,
  CODE_FOR_reload_pti_di_store = 3651,
  CODE_FOR_reload_kf_di_store = 3652,
  CODE_FOR_reload_if_di_store = 3653,
  CODE_FOR_reload_tf_di_store = 3654,
  CODE_FOR_reload_oo_di_store = 3655,
  CODE_FOR_reload_xo_di_store = 3656,
  CODE_FOR_reload_v16qi_si_load = 3657,
  CODE_FOR_reload_v8hi_si_load = 3658,
  CODE_FOR_reload_v4si_si_load = 3659,
  CODE_FOR_reload_v2di_si_load = 3660,
  CODE_FOR_reload_v4sf_si_load = 3661,
  CODE_FOR_reload_v2df_si_load = 3662,
  CODE_FOR_reload_v1ti_si_load = 3663,
  CODE_FOR_reload_sf_si_load = 3664,
  CODE_FOR_reload_sd_si_load = 3665,
  CODE_FOR_reload_si_si_load = 3666,
  CODE_FOR_reload_df_si_load = 3667,
  CODE_FOR_reload_dd_si_load = 3668,
  CODE_FOR_reload_di_si_load = 3669,
  CODE_FOR_reload_ti_si_load = 3670,
  CODE_FOR_reload_pti_si_load = 3671,
  CODE_FOR_reload_kf_si_load = 3672,
  CODE_FOR_reload_if_si_load = 3673,
  CODE_FOR_reload_tf_si_load = 3674,
  CODE_FOR_reload_oo_si_load = 3675,
  CODE_FOR_reload_xo_si_load = 3676,
  CODE_FOR_reload_v16qi_di_load = 3677,
  CODE_FOR_reload_v8hi_di_load = 3678,
  CODE_FOR_reload_v4si_di_load = 3679,
  CODE_FOR_reload_v2di_di_load = 3680,
  CODE_FOR_reload_v4sf_di_load = 3681,
  CODE_FOR_reload_v2df_di_load = 3682,
  CODE_FOR_reload_v1ti_di_load = 3683,
  CODE_FOR_reload_sf_di_load = 3684,
  CODE_FOR_reload_sd_di_load = 3685,
  CODE_FOR_reload_si_di_load = 3686,
  CODE_FOR_reload_df_di_load = 3687,
  CODE_FOR_reload_dd_di_load = 3688,
  CODE_FOR_reload_di_di_load = 3689,
  CODE_FOR_reload_ti_di_load = 3690,
  CODE_FOR_reload_pti_di_load = 3691,
  CODE_FOR_reload_kf_di_load = 3692,
  CODE_FOR_reload_if_di_load = 3693,
  CODE_FOR_reload_tf_di_load = 3694,
  CODE_FOR_reload_oo_di_load = 3695,
  CODE_FOR_reload_xo_di_load = 3696,
  CODE_FOR_setmemsi = 3697,
  CODE_FOR_cmpstrnsi = 3698,
  CODE_FOR_cmpstrsi = 3699,
  CODE_FOR_cmpmemsi = 3700,
  CODE_FOR_cpymemsi = 3701,
  CODE_FOR_movmemsi = 3702,
   CODE_FOR_tls_get_tpointer = CODE_FOR_nothing,
   CODE_FOR_tls_get_addrsi = CODE_FOR_nothing,
   CODE_FOR_tls_get_addrdi = CODE_FOR_nothing,
  CODE_FOR_allocate_stack = 3703,
  CODE_FOR_save_stack_function = 3704,
  CODE_FOR_restore_stack_function = 3705,
  CODE_FOR_restore_stack_block = 3706,
  CODE_FOR_save_stack_nonlocal = 3707,
  CODE_FOR_restore_stack_nonlocal = 3708,
  CODE_FOR_load_toc_v4_PIC_1 = 3709,
  CODE_FOR_load_toc_v4_PIC_1b = 3710,
  CODE_FOR_builtin_setjmp_receiver = 3711,
  CODE_FOR_call = 3712,
  CODE_FOR_call_value = 3713,
  CODE_FOR_untyped_call = 3714,
  CODE_FOR_sibcall = 3715,
  CODE_FOR_sibcall_value = 3716,
  CODE_FOR_sibcall_epilogue = 3717,
  CODE_FOR_probe_stack_address = 3718,
  CODE_FOR_cbranchsi4 = 3719,
  CODE_FOR_cbranchdi4 = 3720,
  CODE_FOR_cbranchsf4 = 3721,
  CODE_FOR_cbranchdf4 = 3722,
  CODE_FOR_cbranchtf4 = 3723,
  CODE_FOR_cbranchif4 = 3724,
  CODE_FOR_cbranchkf4 = 3725,
  CODE_FOR_cbranchdd4 = 3726,
  CODE_FOR_cbranchtd4 = 3727,
  CODE_FOR_cbranchcc4 = 3728,
  CODE_FOR_cstoresi4_signed = 3729,
  CODE_FOR_cstoredi4_signed = 3730,
  CODE_FOR_cstoresi4_unsigned = 3731,
  CODE_FOR_cstoredi4_unsigned = 3732,
  CODE_FOR_cstore_si_as_di = 3733,
  CODE_FOR_cstoresi4_signed_imm = 3734,
  CODE_FOR_cstoredi4_signed_imm = 3735,
  CODE_FOR_cstoresi4_unsigned_imm = 3736,
  CODE_FOR_cstoredi4_unsigned_imm = 3737,
  CODE_FOR_cstoresi4 = 3738,
  CODE_FOR_cstoredi4 = 3739,
  CODE_FOR_cstoresf4 = 3740,
  CODE_FOR_cstoredf4 = 3741,
  CODE_FOR_cstoretf4 = 3742,
  CODE_FOR_cstoreif4 = 3743,
  CODE_FOR_cstorekf4 = 3744,
  CODE_FOR_cstoredd4 = 3745,
  CODE_FOR_cstoretd4 = 3746,
  CODE_FOR_stack_protect_set = 3747,
  CODE_FOR_stack_protect_test = 3748,
  CODE_FOR_eqsi3 = 3749,
  CODE_FOR_eqdi3 = 3750,
  CODE_FOR_nesi3 = 3751,
  CODE_FOR_nedi3 = 3752,
  CODE_FOR_indirect_jump = 3753,
  CODE_FOR_tablejump = 3754,
  CODE_FOR_tablejumpsi_normal = 3755,
  CODE_FOR_tablejumpdi_normal = 3756,
  CODE_FOR_tablejumpsi_absolute = 3757,
  CODE_FOR_tablejumpdi_absolute = 3758,
  CODE_FOR_tablejumpsi_nospec = 3759,
  CODE_FOR_tablejumpdi_nospec = 3760,
  CODE_FOR_tablejumpsi_absolute_nospec = 3761,
  CODE_FOR_tablejumpdi_absolute_nospec = 3762,
  CODE_FOR_doloop_end = 3763,
  CODE_FOR_ctrsi = 3764,
  CODE_FOR_ctrdi = 3765,
  CODE_FOR_ctrapsi4 = 3766,
  CODE_FOR_ctrapdi4 = 3767,
  CODE_FOR_prologue = 3768,
  CODE_FOR_epilogue = 3769,
  CODE_FOR_movsi_to_cr_one = 3770,
  CODE_FOR_eh_return = 3771,
  CODE_FOR_split_stack_prologue = 3772,
  CODE_FOR_load_split_stack_limit = 3773,
  CODE_FOR_split_stack_space_check = 3774,
  CODE_FOR_fmasf4 = 3775,
  CODE_FOR_fmadf4 = 3776,
  CODE_FOR_fmav4sf4 = 3777,
  CODE_FOR_fmav2df4 = 3778,
  CODE_FOR_fmakf4 = 3779,
  CODE_FOR_fmatf4 = 3780,
  CODE_FOR_fmssf4 = 3781,
  CODE_FOR_fmsdf4 = 3782,
  CODE_FOR_fmsv4sf4 = 3783,
  CODE_FOR_fmsv2df4 = 3784,
  CODE_FOR_fmskf4 = 3785,
  CODE_FOR_fmstf4 = 3786,
  CODE_FOR_fnmasf4 = 3787,
  CODE_FOR_fnmadf4 = 3788,
  CODE_FOR_fnmav4sf4 = 3789,
  CODE_FOR_fnmav2df4 = 3790,
  CODE_FOR_fnmakf4 = 3791,
  CODE_FOR_fnmatf4 = 3792,
  CODE_FOR_fnmssf4 = 3793,
  CODE_FOR_fnmsdf4 = 3794,
  CODE_FOR_fnmsv4sf4 = 3795,
  CODE_FOR_fnmsv2df4 = 3796,
  CODE_FOR_fnmskf4 = 3797,
  CODE_FOR_fnmstf4 = 3798,
  CODE_FOR_nfmasf4 = 3799,
  CODE_FOR_nfmadf4 = 3800,
  CODE_FOR_nfmav4sf4 = 3801,
  CODE_FOR_nfmav2df4 = 3802,
  CODE_FOR_nfmakf4 = 3803,
  CODE_FOR_nfmatf4 = 3804,
  CODE_FOR_nfmssf4 = 3805,
  CODE_FOR_nfmsdf4 = 3806,
  CODE_FOR_nfmsv4sf4 = 3807,
  CODE_FOR_nfmsv2df4 = 3808,
  CODE_FOR_nfmskf4 = 3809,
  CODE_FOR_nfmstf4 = 3810,
  CODE_FOR_rs6000_get_timebase = 3811,
  CODE_FOR_rs6000_mffsl = 3812,
  CODE_FOR_unpacktf = 3813,
  CODE_FOR_unpackif = 3814,
  CODE_FOR_unpacktd = 3815,
  CODE_FOR_packtf = 3816,
  CODE_FOR_packif = 3817,
  CODE_FOR_packtd = 3818,
  CODE_FOR_copysignkf3 = 3819,
  CODE_FOR_copysigntf3 = 3820,
  CODE_FOR_darn_32_si = 3821,
  CODE_FOR_darn_32_di = 3822,
  CODE_FOR_darn_64_si = 3823,
  CODE_FOR_darn_64_di = 3824,
  CODE_FOR_darn_raw_si = 3825,
  CODE_FOR_darn_raw_di = 3826,
  CODE_FOR_cmprb = 3827,
  CODE_FOR_cmprb2 = 3828,
  CODE_FOR_cmpeqb = 3829,
  CODE_FOR_mem_thread_fence = 3830,
  CODE_FOR_hwsync = 3831,
  CODE_FOR_lwsync = 3832,
  CODE_FOR_atomic_loadqi = 3833,
  CODE_FOR_atomic_loadhi = 3834,
  CODE_FOR_atomic_loadsi = 3835,
  CODE_FOR_atomic_loaddi = 3836,
  CODE_FOR_atomic_loadti = 3837,
  CODE_FOR_atomic_storeqi = 3838,
  CODE_FOR_atomic_storehi = 3839,
  CODE_FOR_atomic_storesi = 3840,
  CODE_FOR_atomic_storedi = 3841,
  CODE_FOR_atomic_storeti = 3842,
  CODE_FOR_load_lockedti = 3843,
  CODE_FOR_store_conditionalti = 3844,
  CODE_FOR_atomic_compare_and_swapqi = 3845,
  CODE_FOR_atomic_compare_and_swaphi = 3846,
  CODE_FOR_atomic_compare_and_swapsi = 3847,
  CODE_FOR_atomic_compare_and_swapdi = 3848,
  CODE_FOR_atomic_compare_and_swapti = 3849,
  CODE_FOR_atomic_exchangeqi = 3850,
  CODE_FOR_atomic_exchangehi = 3851,
  CODE_FOR_atomic_exchangesi = 3852,
  CODE_FOR_atomic_exchangedi = 3853,
  CODE_FOR_atomic_exchangeti = 3854,
  CODE_FOR_atomic_addqi = 3855,
  CODE_FOR_atomic_subqi = 3856,
  CODE_FOR_atomic_orqi = 3857,
  CODE_FOR_atomic_xorqi = 3858,
  CODE_FOR_atomic_andqi = 3859,
  CODE_FOR_atomic_addhi = 3860,
  CODE_FOR_atomic_subhi = 3861,
  CODE_FOR_atomic_orhi = 3862,
  CODE_FOR_atomic_xorhi = 3863,
  CODE_FOR_atomic_andhi = 3864,
  CODE_FOR_atomic_addsi = 3865,
  CODE_FOR_atomic_subsi = 3866,
  CODE_FOR_atomic_orsi = 3867,
  CODE_FOR_atomic_xorsi = 3868,
  CODE_FOR_atomic_andsi = 3869,
  CODE_FOR_atomic_adddi = 3870,
  CODE_FOR_atomic_subdi = 3871,
  CODE_FOR_atomic_ordi = 3872,
  CODE_FOR_atomic_xordi = 3873,
  CODE_FOR_atomic_anddi = 3874,
  CODE_FOR_atomic_addti = 3875,
  CODE_FOR_atomic_subti = 3876,
  CODE_FOR_atomic_orti = 3877,
  CODE_FOR_atomic_xorti = 3878,
  CODE_FOR_atomic_andti = 3879,
  CODE_FOR_atomic_nandqi = 3880,
  CODE_FOR_atomic_nandhi = 3881,
  CODE_FOR_atomic_nandsi = 3882,
  CODE_FOR_atomic_nanddi = 3883,
  CODE_FOR_atomic_nandti = 3884,
  CODE_FOR_atomic_fetch_addqi = 3885,
  CODE_FOR_atomic_fetch_subqi = 3886,
  CODE_FOR_atomic_fetch_orqi = 3887,
  CODE_FOR_atomic_fetch_xorqi = 3888,
  CODE_FOR_atomic_fetch_andqi = 3889,
  CODE_FOR_atomic_fetch_addhi = 3890,
  CODE_FOR_atomic_fetch_subhi = 3891,
  CODE_FOR_atomic_fetch_orhi = 3892,
  CODE_FOR_atomic_fetch_xorhi = 3893,
  CODE_FOR_atomic_fetch_andhi = 3894,
  CODE_FOR_atomic_fetch_addsi = 3895,
  CODE_FOR_atomic_fetch_subsi = 3896,
  CODE_FOR_atomic_fetch_orsi = 3897,
  CODE_FOR_atomic_fetch_xorsi = 3898,
  CODE_FOR_atomic_fetch_andsi = 3899,
  CODE_FOR_atomic_fetch_adddi = 3900,
  CODE_FOR_atomic_fetch_subdi = 3901,
  CODE_FOR_atomic_fetch_ordi = 3902,
  CODE_FOR_atomic_fetch_xordi = 3903,
  CODE_FOR_atomic_fetch_anddi = 3904,
  CODE_FOR_atomic_fetch_addti = 3905,
  CODE_FOR_atomic_fetch_subti = 3906,
  CODE_FOR_atomic_fetch_orti = 3907,
  CODE_FOR_atomic_fetch_xorti = 3908,
  CODE_FOR_atomic_fetch_andti = 3909,
  CODE_FOR_atomic_fetch_nandqi = 3910,
  CODE_FOR_atomic_fetch_nandhi = 3911,
  CODE_FOR_atomic_fetch_nandsi = 3912,
  CODE_FOR_atomic_fetch_nanddi = 3913,
  CODE_FOR_atomic_fetch_nandti = 3914,
  CODE_FOR_atomic_add_fetchqi = 3915,
  CODE_FOR_atomic_sub_fetchqi = 3916,
  CODE_FOR_atomic_or_fetchqi = 3917,
  CODE_FOR_atomic_xor_fetchqi = 3918,
  CODE_FOR_atomic_and_fetchqi = 3919,
  CODE_FOR_atomic_add_fetchhi = 3920,
  CODE_FOR_atomic_sub_fetchhi = 3921,
  CODE_FOR_atomic_or_fetchhi = 3922,
  CODE_FOR_atomic_xor_fetchhi = 3923,
  CODE_FOR_atomic_and_fetchhi = 3924,
  CODE_FOR_atomic_add_fetchsi = 3925,
  CODE_FOR_atomic_sub_fetchsi = 3926,
  CODE_FOR_atomic_or_fetchsi = 3927,
  CODE_FOR_atomic_xor_fetchsi = 3928,
  CODE_FOR_atomic_and_fetchsi = 3929,
  CODE_FOR_atomic_add_fetchdi = 3930,
  CODE_FOR_atomic_sub_fetchdi = 3931,
  CODE_FOR_atomic_or_fetchdi = 3932,
  CODE_FOR_atomic_xor_fetchdi = 3933,
  CODE_FOR_atomic_and_fetchdi = 3934,
  CODE_FOR_atomic_add_fetchti = 3935,
  CODE_FOR_atomic_sub_fetchti = 3936,
  CODE_FOR_atomic_or_fetchti = 3937,
  CODE_FOR_atomic_xor_fetchti = 3938,
  CODE_FOR_atomic_and_fetchti = 3939,
  CODE_FOR_atomic_nand_fetchqi = 3940,
  CODE_FOR_atomic_nand_fetchhi = 3941,
  CODE_FOR_atomic_nand_fetchsi = 3942,
  CODE_FOR_atomic_nand_fetchdi = 3943,
  CODE_FOR_atomic_nand_fetchti = 3944,
  CODE_FOR_movv16qi = 3945,
  CODE_FOR_movv8hi = 3946,
  CODE_FOR_movv4si = 3947,
  CODE_FOR_movv2di = 3948,
  CODE_FOR_movv4sf = 3949,
  CODE_FOR_movv2df = 3950,
  CODE_FOR_movv1ti = 3951,
  CODE_FOR_movkf = 3952,
  CODE_FOR_addv4sf3 = 3953,
  CODE_FOR_addv2df3 = 3954,
  CODE_FOR_subv4sf3 = 3955,
  CODE_FOR_subv2df3 = 3956,
  CODE_FOR_mulv4sf3 = 3957,
  CODE_FOR_mulv2df3 = 3958,
  CODE_FOR_divv4sf3 = 3959,
  CODE_FOR_divv2df3 = 3960,
  CODE_FOR_negv4sf2 = 3961,
  CODE_FOR_negv2df2 = 3962,
  CODE_FOR_absv4sf2 = 3963,
  CODE_FOR_absv2df2 = 3964,
  CODE_FOR_sminv4sf3 = 3965,
  CODE_FOR_sminv2df3 = 3966,
  CODE_FOR_smaxv4sf3 = 3967,
  CODE_FOR_smaxv2df3 = 3968,
  CODE_FOR_sqrtv4sf2 = 3969,
  CODE_FOR_sqrtv2df2 = 3970,
  CODE_FOR_rsqrtev4sf2 = 3971,
  CODE_FOR_rsqrtev2df2 = 3972,
  CODE_FOR_rev4sf2 = 3973,
  CODE_FOR_rev2df2 = 3974,
  CODE_FOR_ftruncv4sf2 = 3975,
  CODE_FOR_ftruncv2df2 = 3976,
  CODE_FOR_vector_ceilv4sf2 = 3977,
  CODE_FOR_vector_ceilv2df2 = 3978,
  CODE_FOR_vector_floorv4sf2 = 3979,
  CODE_FOR_vector_floorv2df2 = 3980,
  CODE_FOR_vector_btruncv4sf2 = 3981,
  CODE_FOR_vector_btruncv2df2 = 3982,
  CODE_FOR_vector_copysignv4sf3 = 3983,
  CODE_FOR_vector_copysignv2df3 = 3984,
  CODE_FOR_vcond_mask_v16qiv16qi = 3985,
  CODE_FOR_vcond_mask_v8hiv8hi = 3986,
  CODE_FOR_vcond_mask_v4siv4si = 3987,
  CODE_FOR_vcond_mask_v2div2di = 3988,
  CODE_FOR_vcond_mask_v4sfv4si = 3989,
  CODE_FOR_vcond_mask_v2dfv2di = 3990,
  CODE_FOR_vec_cmpv16qiv16qi = 3991,
  CODE_FOR_vec_cmpv8hiv8hi = 3992,
  CODE_FOR_vec_cmpv4siv4si = 3993,
  CODE_FOR_vec_cmpv2div2di = 3994,
  CODE_FOR_vec_cmpv1tiv1ti = 3995,
  CODE_FOR_vec_cmpuv16qiv16qi = 3996,
  CODE_FOR_vec_cmpuv8hiv8hi = 3997,
  CODE_FOR_vec_cmpuv4siv4si = 3998,
  CODE_FOR_vec_cmpuv2div2di = 3999,
  CODE_FOR_vec_cmpuv1tiv1ti = 4000,
  CODE_FOR_vec_cmpv4sfv4si = 4001,
  CODE_FOR_vec_cmpv2dfv2di = 4002,
  CODE_FOR_vector_eqv16qi = 4003,
  CODE_FOR_vector_eqv8hi = 4004,
  CODE_FOR_vector_eqv4si = 4005,
  CODE_FOR_vector_eqv2di = 4006,
  CODE_FOR_vector_eqv4sf = 4007,
  CODE_FOR_vector_eqv2df = 4008,
  CODE_FOR_vector_eqv1ti = 4009,
  CODE_FOR_vector_gtv16qi = 4010,
  CODE_FOR_vector_gtv8hi = 4011,
  CODE_FOR_vector_gtv4si = 4012,
  CODE_FOR_vector_gtv2di = 4013,
  CODE_FOR_vector_gtv4sf = 4014,
  CODE_FOR_vector_gtv2df = 4015,
  CODE_FOR_vector_gtv1ti = 4016,
  CODE_FOR_vector_nltv16qi = 4017,
  CODE_FOR_vector_nltv8hi = 4018,
  CODE_FOR_vector_nltv4si = 4019,
  CODE_FOR_vector_nltv2di = 4020,
  CODE_FOR_vector_nltv1ti = 4021,
  CODE_FOR_vector_gtuv16qi = 4022,
  CODE_FOR_vector_gtuv8hi = 4023,
  CODE_FOR_vector_gtuv4si = 4024,
  CODE_FOR_vector_gtuv2di = 4025,
  CODE_FOR_vector_gtuv1ti = 4026,
  CODE_FOR_vector_nltuv16qi = 4027,
  CODE_FOR_vector_nltuv8hi = 4028,
  CODE_FOR_vector_nltuv4si = 4029,
  CODE_FOR_vector_nltuv2di = 4030,
  CODE_FOR_vector_nltuv1ti = 4031,
  CODE_FOR_vector_geuv16qi = 4032,
  CODE_FOR_vector_geuv8hi = 4033,
  CODE_FOR_vector_geuv4si = 4034,
  CODE_FOR_vector_geuv2di = 4035,
  CODE_FOR_vector_geuv1ti = 4036,
  CODE_FOR_vector_ngtv16qi = 4037,
  CODE_FOR_vector_ngtv8hi = 4038,
  CODE_FOR_vector_ngtv4si = 4039,
  CODE_FOR_vector_ngtv2di = 4040,
  CODE_FOR_vector_ngtv1ti = 4041,
  CODE_FOR_vector_ngtuv16qi = 4042,
  CODE_FOR_vector_ngtuv8hi = 4043,
  CODE_FOR_vector_ngtuv4si = 4044,
  CODE_FOR_vector_ngtuv2di = 4045,
  CODE_FOR_vector_ngtuv1ti = 4046,
  CODE_FOR_vector_gev4sf = 4047,
  CODE_FOR_vector_gev2df = 4048,
  CODE_FOR_vector_select_v16qi = 4049,
  CODE_FOR_vector_select_v8hi = 4050,
  CODE_FOR_vector_select_v4si = 4051,
  CODE_FOR_vector_select_v2di = 4052,
  CODE_FOR_vector_select_v4sf = 4053,
  CODE_FOR_vector_select_v2df = 4054,
  CODE_FOR_vector_select_v1ti = 4055,
  CODE_FOR_vector_select_ti = 4056,
  CODE_FOR_vector_select_kf = 4057,
  CODE_FOR_vector_select_tf = 4058,
  CODE_FOR_vector_select_v16qi_uns = 4059,
  CODE_FOR_vector_select_v8hi_uns = 4060,
  CODE_FOR_vector_select_v4si_uns = 4061,
  CODE_FOR_vector_select_v2di_uns = 4062,
  CODE_FOR_vector_select_v4sf_uns = 4063,
  CODE_FOR_vector_select_v2df_uns = 4064,
  CODE_FOR_vector_select_v1ti_uns = 4065,
  CODE_FOR_vector_select_ti_uns = 4066,
  CODE_FOR_vector_select_kf_uns = 4067,
  CODE_FOR_vector_select_tf_uns = 4068,
  CODE_FOR_vector_eq_v16qi_p = 4069,
  CODE_FOR_vector_eq_v8hi_p = 4070,
  CODE_FOR_vector_eq_v4si_p = 4071,
  CODE_FOR_vector_eq_v2di_p = 4072,
  CODE_FOR_vector_eq_v4sf_p = 4073,
  CODE_FOR_vector_eq_v2df_p = 4074,
  CODE_FOR_vector_eq_v1ti_p = 4075,
  CODE_FOR_vector_ne_v4si_p = 4076,
  CODE_FOR_vector_ne_v8hi_p = 4077,
  CODE_FOR_vector_ne_v16qi_p = 4078,
  CODE_FOR_vector_ae_v4si_p = 4079,
  CODE_FOR_vector_ae_v8hi_p = 4080,
  CODE_FOR_vector_ae_v16qi_p = 4081,
  CODE_FOR_vector_nez_v4si_p = 4082,
  CODE_FOR_vector_nez_v8hi_p = 4083,
  CODE_FOR_vector_nez_v16qi_p = 4084,
  CODE_FOR_vector_ne_v2di_p = 4085,
  CODE_FOR_vector_ne_v1ti_p = 4086,
  CODE_FOR_vector_ae_v2di_p = 4087,
  CODE_FOR_vector_ae_v1ti_p = 4088,
  CODE_FOR_vector_ne_v4sf_p = 4089,
  CODE_FOR_vector_ne_v2df_p = 4090,
  CODE_FOR_vector_ae_v4sf_p = 4091,
  CODE_FOR_vector_ae_v2df_p = 4092,
  CODE_FOR_vector_gt_v16qi_p = 4093,
  CODE_FOR_vector_gt_v8hi_p = 4094,
  CODE_FOR_vector_gt_v4si_p = 4095,
  CODE_FOR_vector_gt_v2di_p = 4096,
  CODE_FOR_vector_gt_v4sf_p = 4097,
  CODE_FOR_vector_gt_v2df_p = 4098,
  CODE_FOR_vector_gt_v1ti_p = 4099,
  CODE_FOR_vector_ge_v4sf_p = 4100,
  CODE_FOR_vector_ge_v2df_p = 4101,
  CODE_FOR_vector_gtu_v16qi_p = 4102,
  CODE_FOR_vector_gtu_v8hi_p = 4103,
  CODE_FOR_vector_gtu_v4si_p = 4104,
  CODE_FOR_vector_gtu_v2di_p = 4105,
  CODE_FOR_vector_gtu_v1ti_p = 4106,
  CODE_FOR_cr6_test_for_zero = 4107,
  CODE_FOR_cr6_test_for_zero_reverse = 4108,
  CODE_FOR_cr6_test_for_lt = 4109,
  CODE_FOR_cr6_test_for_lt_reverse = 4110,
  CODE_FOR_clzv16qi2 = 4111,
  CODE_FOR_clzv8hi2 = 4112,
  CODE_FOR_clzv4si2 = 4113,
  CODE_FOR_clzv2di2 = 4114,
  CODE_FOR_ctzv16qi2 = 4115,
  CODE_FOR_ctzv8hi2 = 4116,
  CODE_FOR_ctzv4si2 = 4117,
  CODE_FOR_ctzv2di2 = 4118,
  CODE_FOR_popcountv16qi2 = 4119,
  CODE_FOR_popcountv8hi2 = 4120,
  CODE_FOR_popcountv4si2 = 4121,
  CODE_FOR_popcountv2di2 = 4122,
  CODE_FOR_parityv8hi2 = 4123,
  CODE_FOR_parityv4si2 = 4124,
  CODE_FOR_parityv2di2 = 4125,
  CODE_FOR_parityv1ti2 = 4126,
  CODE_FOR_parityti2 = 4127,
  CODE_FOR_floatv4siv4sf2 = 4128,
  CODE_FOR_floatv2div2df2 = 4129,
  CODE_FOR_floatunsv4siv4sf2 = 4130,
  CODE_FOR_floatunsv2div2df2 = 4131,
  CODE_FOR_fix_truncv4sfv4si2 = 4132,
  CODE_FOR_fix_truncv2dfv2di2 = 4133,
  CODE_FOR_fixuns_truncv4sfv4si2 = 4134,
  CODE_FOR_fixuns_truncv2dfv2di2 = 4135,
  CODE_FOR_vec_initv16qiqi = 4136,
  CODE_FOR_vec_initv8hihi = 4137,
  CODE_FOR_vec_initv4sisi = 4138,
  CODE_FOR_vec_initv2didi = 4139,
  CODE_FOR_vec_initv4sfsf = 4140,
  CODE_FOR_vec_initv2dfdf = 4141,
  CODE_FOR_vec_setv16qi = 4142,
  CODE_FOR_vec_setv8hi = 4143,
  CODE_FOR_vec_setv4si = 4144,
  CODE_FOR_vec_setv2di = 4145,
  CODE_FOR_vec_setv4sf = 4146,
  CODE_FOR_vec_setv2df = 4147,
  CODE_FOR_vec_extractv16qiqi = 4148,
  CODE_FOR_vec_extractv8hihi = 4149,
  CODE_FOR_vec_extractv4sisi = 4150,
  CODE_FOR_vec_extractv2didi = 4151,
  CODE_FOR_vec_extractv4sfsf = 4152,
  CODE_FOR_vec_extractv2dfdf = 4153,
  CODE_FOR_vec_pack_trunc_v2df = 4154,
  CODE_FOR_vec_pack_sfix_trunc_v2df = 4155,
  CODE_FOR_vec_pack_ufix_trunc_v2df = 4156,
  CODE_FOR_vec_unpacks_hi_v4sf = 4157,
  CODE_FOR_vec_unpacks_lo_v4sf = 4158,
  CODE_FOR_vec_unpacks_float_hi_v4si = 4159,
  CODE_FOR_vec_unpacks_float_lo_v4si = 4160,
  CODE_FOR_vec_unpacku_float_hi_v4si = 4161,
  CODE_FOR_vec_unpacku_float_lo_v4si = 4162,
  CODE_FOR_vec_realign_load_v16qi = 4163,
  CODE_FOR_vec_realign_load_v8hi = 4164,
  CODE_FOR_vec_realign_load_v4si = 4165,
  CODE_FOR_vec_realign_load_v4sf = 4166,
  CODE_FOR_movmisalignv4si = 4167,
  CODE_FOR_movmisalignv4sf = 4168,
  CODE_FOR_movmisalignv2di = 4169,
  CODE_FOR_movmisalignv2df = 4170,
  CODE_FOR_movmisalignv1ti = 4171,
  CODE_FOR_movmisalignkf = 4172,
  CODE_FOR_movmisaligntf = 4173,
  CODE_FOR_vec_shr_v16qi = 4174,
  CODE_FOR_vec_shr_v8hi = 4175,
  CODE_FOR_vec_shr_v4si = 4176,
  CODE_FOR_vec_shr_v2di = 4177,
  CODE_FOR_vec_shr_v4sf = 4178,
  CODE_FOR_vec_shr_v2df = 4179,
  CODE_FOR_vec_shr_v1ti = 4180,
  CODE_FOR_vec_shr_ti = 4181,
  CODE_FOR_vec_shr_kf = 4182,
  CODE_FOR_vec_shr_tf = 4183,
  CODE_FOR_vrotlv16qi3 = 4184,
  CODE_FOR_vrotlv8hi3 = 4185,
  CODE_FOR_vrotlv4si3 = 4186,
  CODE_FOR_vrotlv2di3 = 4187,
  CODE_FOR_vrotlv1ti3 = 4188,
  CODE_FOR_vrotrv16qi3 = 4189,
  CODE_FOR_vrotrv8hi3 = 4190,
  CODE_FOR_vrotrv4si3 = 4191,
  CODE_FOR_vrotrv2di3 = 4192,
  CODE_FOR_vashlv16qi3 = 4193,
  CODE_FOR_vashlv8hi3 = 4194,
  CODE_FOR_vashlv4si3 = 4195,
  CODE_FOR_vashlv2di3 = 4196,
  CODE_FOR_vashlv1ti3 = 4197,
  CODE_FOR_vashlti3 = 4198,
  CODE_FOR_vlshrv16qi3 = 4199,
  CODE_FOR_vlshrv8hi3 = 4200,
  CODE_FOR_vlshrv4si3 = 4201,
  CODE_FOR_vlshrv2di3 = 4202,
  CODE_FOR_vlshrv1ti3 = 4203,
  CODE_FOR_vlshrti3 = 4204,
  CODE_FOR_vashrv16qi3 = 4205,
  CODE_FOR_vashrv8hi3 = 4206,
  CODE_FOR_vashrv4si3 = 4207,
  CODE_FOR_vashrv2di3 = 4208,
  CODE_FOR_vashrv1ti3 = 4209,
  CODE_FOR_reduc_plus_scal_v4sf = 4210,
  CODE_FOR_reduc_smin_scal_v4sf = 4211,
  CODE_FOR_reduc_smax_scal_v4sf = 4212,
  CODE_FOR_reduc_plus_scal_v2df = 4213,
  CODE_FOR_reduc_smin_scal_v2df = 4214,
  CODE_FOR_reduc_smax_scal_v2df = 4215,
  CODE_FOR_vsx_load_v16qi = 4216,
  CODE_FOR_vsx_load_v8hi = 4217,
  CODE_FOR_vsx_load_v4si = 4218,
  CODE_FOR_vsx_load_v2di = 4219,
  CODE_FOR_vsx_load_v4sf = 4220,
  CODE_FOR_vsx_load_v2df = 4221,
  CODE_FOR_vsx_load_v1ti = 4222,
  CODE_FOR_vsx_load_kf = 4223,
  CODE_FOR_vsx_load_tf = 4224,
  CODE_FOR_vsx_load_ti = 4225,
  CODE_FOR_vsx_store_v16qi = 4226,
  CODE_FOR_vsx_store_v8hi = 4227,
  CODE_FOR_vsx_store_v4si = 4228,
  CODE_FOR_vsx_store_v2di = 4229,
  CODE_FOR_vsx_store_v4sf = 4230,
  CODE_FOR_vsx_store_v2df = 4231,
  CODE_FOR_vsx_store_v1ti = 4232,
  CODE_FOR_vsx_store_kf = 4233,
  CODE_FOR_vsx_store_tf = 4234,
  CODE_FOR_vsx_store_ti = 4235,
  CODE_FOR_vsx_ld_elemrev_v8hi = 4236,
  CODE_FOR_vsx_ld_elemrev_v16qi = 4237,
  CODE_FOR_vsx_st_elemrev_v8hi = 4238,
  CODE_FOR_vsx_st_elemrev_v16qi = 4239,
  CODE_FOR_vsx_tdivdf3_fg = 4240,
  CODE_FOR_vsx_tdivv4sf3_fg = 4241,
  CODE_FOR_vsx_tdivv2df3_fg = 4242,
  CODE_FOR_vsx_tdivdf3_fe = 4243,
  CODE_FOR_vsx_tdivv4sf3_fe = 4244,
  CODE_FOR_vsx_tdivv2df3_fe = 4245,
  CODE_FOR_vsx_tsqrtdf2_fg = 4246,
  CODE_FOR_vsx_tsqrtv4sf2_fg = 4247,
  CODE_FOR_vsx_tsqrtv2df2_fg = 4248,
  CODE_FOR_vsx_tsqrtdf2_fe = 4249,
  CODE_FOR_vsx_tsqrtv4sf2_fe = 4250,
  CODE_FOR_vsx_tsqrtv2df2_fe = 4251,
  CODE_FOR_xvtlsbbo = 4252,
  CODE_FOR_xvtlsbbz = 4253,
  CODE_FOR_vsx_xvcvspdp = 4254,
  CODE_FOR_vsx_xvcvsxddp_scale = 4255,
  CODE_FOR_vsx_xvcvuxddp_scale = 4256,
  CODE_FOR_vsx_xvcvdpsxds_scale = 4257,
  CODE_FOR_vsx_xvcvdpuxds_scale = 4258,
  CODE_FOR_vsx_xvcvsxwdp = 4259,
  CODE_FOR_vsx_xvcvuxwdp = 4260,
  CODE_FOR_vsx_xvcvspsxds = 4261,
  CODE_FOR_vsx_xvcvspuxds = 4262,
  CODE_FOR_vsignede_v4sf = 4263,
  CODE_FOR_vsignedo_v4sf = 4264,
  CODE_FOR_vunsignede_v4sf = 4265,
  CODE_FOR_vunsignedo_v4sf = 4266,
  CODE_FOR_float2_v2df = 4267,
  CODE_FOR_float2_v2di = 4268,
  CODE_FOR_uns_float2_v2di = 4269,
  CODE_FOR_floatev2df = 4270,
  CODE_FOR_floatev2di = 4271,
  CODE_FOR_unsfloatev2di = 4272,
  CODE_FOR_floatov2df = 4273,
  CODE_FOR_floatov2di = 4274,
  CODE_FOR_unsfloatov2di = 4275,
  CODE_FOR_vsigned2_v2df = 4276,
  CODE_FOR_vsignedo_v2df = 4277,
  CODE_FOR_vsignede_v2df = 4278,
  CODE_FOR_vunsigned2_v2df = 4279,
  CODE_FOR_vunsignedo_v2df = 4280,
  CODE_FOR_vunsignede_v2df = 4281,
  CODE_FOR_vsx_init_v4si = 4282,
  CODE_FOR_xxgenpcvm_v16qi = 4283,
  CODE_FOR_xxgenpcvm_v8hi = 4284,
  CODE_FOR_xxgenpcvm_v4si = 4285,
  CODE_FOR_xxgenpcvm_v2di = 4286,
  CODE_FOR_vsx_set_v1ti = 4287,
  CODE_FOR_vsx_set_v2df = 4288,
  CODE_FOR_vsx_set_v2di = 4289,
  CODE_FOR_vsx_extract_v2df = 4290,
  CODE_FOR_vsx_extract_v2di = 4291,
  CODE_FOR_vsx_xxpermdi_v16qi = 4292,
  CODE_FOR_vsx_xxpermdi_v8hi = 4293,
  CODE_FOR_vsx_xxpermdi_v4si = 4294,
  CODE_FOR_vsx_xxpermdi_v2di = 4295,
  CODE_FOR_vsx_xxpermdi_v4sf = 4296,
  CODE_FOR_vsx_xxpermdi_v2df = 4297,
  CODE_FOR_vsx_xxpermdi_v1ti = 4298,
  CODE_FOR_vsx_xxpermdi_ti = 4299,
  CODE_FOR_vsx_xxpermdi_kf = 4300,
  CODE_FOR_vsx_xxpermdi_tf = 4301,
  CODE_FOR_vsx_xxpermdi_v16qi_be = 4302,
  CODE_FOR_vsx_xxpermdi_v8hi_be = 4303,
  CODE_FOR_vsx_xxpermdi_v4si_be = 4304,
  CODE_FOR_vsx_xxpermdi_v2di_be = 4305,
  CODE_FOR_vsx_xxpermdi_v4sf_be = 4306,
  CODE_FOR_vsx_xxpermdi_v2df_be = 4307,
  CODE_FOR_vsx_xxpermdi_v1ti_be = 4308,
  CODE_FOR_vsx_xxpermdi_ti_be = 4309,
  CODE_FOR_vsx_xxpermdi_kf_be = 4310,
  CODE_FOR_vsx_xxpermdi_tf_be = 4311,
  CODE_FOR_vsx_extract_v16qi = 4312,
  CODE_FOR_vsx_extract_v8hi = 4313,
  CODE_FOR_vsx_extract_v4si = 4314,
  CODE_FOR_vextractlv4si = 4315,
  CODE_FOR_vextractlv8hi = 4316,
  CODE_FOR_vextractlv16qi = 4317,
  CODE_FOR_vextractlv2di = 4318,
  CODE_FOR_vextractrv4si = 4319,
  CODE_FOR_vextractrv8hi = 4320,
  CODE_FOR_vextractrv16qi = 4321,
  CODE_FOR_vextractrv2di = 4322,
  CODE_FOR_vinsertvl_v4si = 4323,
  CODE_FOR_vinsertvl_v8hi = 4324,
  CODE_FOR_vinsertvl_v16qi = 4325,
  CODE_FOR_vinsertvl_v2di = 4326,
  CODE_FOR_vinsertvr_v4si = 4327,
  CODE_FOR_vinsertvr_v8hi = 4328,
  CODE_FOR_vinsertvr_v16qi = 4329,
  CODE_FOR_vinsertvr_v2di = 4330,
  CODE_FOR_vinsertgl_v4si = 4331,
  CODE_FOR_vinsertgl_v8hi = 4332,
  CODE_FOR_vinsertgl_v16qi = 4333,
  CODE_FOR_vinsertgl_v2di = 4334,
  CODE_FOR_vinsertgr_v4si = 4335,
  CODE_FOR_vinsertgr_v8hi = 4336,
  CODE_FOR_vinsertgr_v16qi = 4337,
  CODE_FOR_vinsertgr_v2di = 4338,
  CODE_FOR_vreplace_elt_v4si = 4339,
  CODE_FOR_vreplace_elt_v4sf = 4340,
  CODE_FOR_vreplace_elt_v2di = 4341,
  CODE_FOR_vreplace_elt_v2df = 4342,
  CODE_FOR_vsx_mergel_v2df = 4343,
  CODE_FOR_vsx_mergel_v2di = 4344,
  CODE_FOR_vsx_mergeh_v2df = 4345,
  CODE_FOR_vsx_mergeh_v2di = 4346,
  CODE_FOR_vsx_splat_v2df = 4347,
  CODE_FOR_vsx_splat_v2di = 4348,
  CODE_FOR_xscmpexpdp_eq = 4389,
  CODE_FOR_xscmpexpdp_lt = 4390,
  CODE_FOR_xscmpexpdp_gt = 4391,
  CODE_FOR_xscmpexpdp_unordered = 4392,
  CODE_FOR_xscmpexpqp_eq_kf = 4393,
  CODE_FOR_xscmpexpqp_lt_kf = 4394,
  CODE_FOR_xscmpexpqp_gt_kf = 4395,
  CODE_FOR_xscmpexpqp_unordered_kf = 4396,
  CODE_FOR_xscmpexpqp_eq_tf = 4397,
  CODE_FOR_xscmpexpqp_lt_tf = 4398,
  CODE_FOR_xscmpexpqp_gt_tf = 4399,
  CODE_FOR_xscmpexpqp_unordered_tf = 4400,
  CODE_FOR_xststdc_sf = 4401,
  CODE_FOR_xststdc_df = 4402,
  CODE_FOR_xststdc_kf = 4403,
  CODE_FOR_xststdc_tf = 4404,
  CODE_FOR_isinfsf2 = 4405,
  CODE_FOR_isinfdf2 = 4406,
  CODE_FOR_isinfkf2 = 4407,
  CODE_FOR_isinftf2 = 4408,
  CODE_FOR_isfinitesf2 = 4409,
  CODE_FOR_isfinitedf2 = 4410,
  CODE_FOR_isfinitekf2 = 4411,
  CODE_FOR_isfinitetf2 = 4412,
  CODE_FOR_isnormalsf2 = 4413,
  CODE_FOR_isnormaldf2 = 4414,
  CODE_FOR_isnormalkf2 = 4415,
  CODE_FOR_isnormaltf2 = 4416,
  CODE_FOR_xststdcnegqp_kf = 4417,
  CODE_FOR_xststdcnegqp_tf = 4418,
  CODE_FOR_xststdcnegsp = 4419,
  CODE_FOR_xststdcnegdp = 4420,
  CODE_FOR_first_match_index_v16qi = 4421,
  CODE_FOR_first_match_index_v8hi = 4422,
  CODE_FOR_first_match_index_v4si = 4423,
  CODE_FOR_first_match_or_eos_index_v16qi = 4424,
  CODE_FOR_first_match_or_eos_index_v8hi = 4425,
  CODE_FOR_first_match_or_eos_index_v4si = 4426,
  CODE_FOR_first_mismatch_index_v16qi = 4427,
  CODE_FOR_first_mismatch_index_v8hi = 4428,
  CODE_FOR_first_mismatch_index_v4si = 4429,
  CODE_FOR_first_mismatch_or_eos_index_v16qi = 4430,
  CODE_FOR_first_mismatch_or_eos_index_v8hi = 4431,
  CODE_FOR_first_mismatch_or_eos_index_v4si = 4432,
  CODE_FOR_lxvl = 4433,
  CODE_FOR_xl_len_r = 4434,
  CODE_FOR_stxvl = 4435,
  CODE_FOR_len_load_v16qi = 4436,
  CODE_FOR_len_store_v16qi = 4437,
  CODE_FOR_xst_len_r = 4438,
  CODE_FOR_vcmpnet = 4439,
  CODE_FOR_insert4b = 4440,
  CODE_FOR_vextract_fp_from_shorth = 4441,
  CODE_FOR_vextract_fp_from_shortl = 4442,
  CODE_FOR_p9_xxbrq_v16qi = 4443,
  CODE_FOR_p9_xxbrd_v2df = 4444,
  CODE_FOR_p9_xxbrw_v4sf = 4445,
  CODE_FOR_revb_v8hi = 4446,
  CODE_FOR_revb_v4si = 4447,
  CODE_FOR_revb_v2di = 4448,
  CODE_FOR_revb_v4sf = 4449,
  CODE_FOR_revb_v2df = 4450,
  CODE_FOR_revb_v1ti = 4451,
  CODE_FOR_revb_v16qi = 4452,
  CODE_FOR_vec_packs_float_v2di = 4453,
  CODE_FOR_vec_packu_float_v2di = 4454,
  CODE_FOR_vec_unpack_sfix_trunc_hi_v4sf = 4455,
  CODE_FOR_vec_unpack_ufix_trunc_hi_v4sf = 4456,
  CODE_FOR_vec_unpack_sfix_trunc_lo_v4sf = 4457,
  CODE_FOR_vec_unpack_ufix_trunc_lo_v4sf = 4458,
  CODE_FOR_xxspltiw_v4sf = 4459,
  CODE_FOR_xxspltidp_v2df = 4460,
  CODE_FOR_xxsplti32dx_v4si = 4461,
  CODE_FOR_xxsplti32dx_v4sf = 4462,
  CODE_FOR_xxpermx = 4463,
  CODE_FOR_altivec_mulv4sf3 = 4464,
  CODE_FOR_mulv4si3 = 4465,
  CODE_FOR_mulv8hi3 = 4466,
  CODE_FOR_vstrir_v8hi = 4467,
  CODE_FOR_vstrir_v16qi = 4468,
  CODE_FOR_vstrir_p_v8hi = 4469,
  CODE_FOR_vstrir_p_v16qi = 4470,
  CODE_FOR_vstril_v8hi = 4471,
  CODE_FOR_vstril_v16qi = 4472,
  CODE_FOR_vstril_p_v8hi = 4473,
  CODE_FOR_vstril_p_v16qi = 4474,
  CODE_FOR_altivec_vmrghb = 4475,
  CODE_FOR_altivec_vmrghh = 4476,
  CODE_FOR_altivec_vmrghw = 4477,
  CODE_FOR_altivec_vmrglb = 4478,
  CODE_FOR_altivec_vmrglh = 4479,
  CODE_FOR_altivec_vmrglw = 4480,
  CODE_FOR_p8_vmrgew_v2df = 4481,
  CODE_FOR_p8_vmrgew_v2di = 4482,
  CODE_FOR_p8_vmrgow_v2df = 4483,
  CODE_FOR_p8_vmrgow_v2di = 4484,
  CODE_FOR_vec_widen_umult_even_v16qi = 4485,
  CODE_FOR_vec_widen_smult_even_v16qi = 4486,
  CODE_FOR_vec_widen_umult_even_v8hi = 4487,
  CODE_FOR_vec_widen_smult_even_v8hi = 4488,
  CODE_FOR_vec_widen_umult_even_v4si = 4489,
  CODE_FOR_vec_widen_umult_even_v2di = 4490,
  CODE_FOR_vec_widen_smult_even_v4si = 4491,
  CODE_FOR_vec_widen_smult_even_v2di = 4492,
  CODE_FOR_vec_widen_umult_odd_v16qi = 4493,
  CODE_FOR_vec_widen_smult_odd_v16qi = 4494,
  CODE_FOR_vec_widen_umult_odd_v8hi = 4495,
  CODE_FOR_vec_widen_smult_odd_v8hi = 4496,
  CODE_FOR_vec_widen_umult_odd_v4si = 4497,
  CODE_FOR_vec_widen_umult_odd_v2di = 4498,
  CODE_FOR_vec_widen_smult_odd_v4si = 4499,
  CODE_FOR_vec_widen_smult_odd_v2di = 4500,
  CODE_FOR_altivec_vrlqmi = 4501,
  CODE_FOR_altivec_vrlqnm = 4502,
  CODE_FOR_altivec_vsum2sws = 4503,
  CODE_FOR_altivec_vsumsws = 4504,
  CODE_FOR_altivec_vspltb = 4505,
  CODE_FOR_altivec_vsplth = 4506,
  CODE_FOR_altivec_vspltw = 4507,
  CODE_FOR_altivec_vspltsf = 4508,
  CODE_FOR_altivec_vperm_v4si = 4509,
  CODE_FOR_altivec_vperm_v8hi = 4510,
  CODE_FOR_altivec_vperm_v16qi = 4511,
  CODE_FOR_altivec_vperm_v4sf = 4512,
  CODE_FOR_altivec_vperm_v2df = 4513,
  CODE_FOR_altivec_vperm_v2di = 4514,
  CODE_FOR_altivec_vperm_v1ti = 4515,
  CODE_FOR_altivec_vperm_ti = 4516,
  CODE_FOR_altivec_vperm_kf = 4517,
  CODE_FOR_altivec_vperm_tf = 4518,
  CODE_FOR_altivec_vperm_v4si_uns = 4519,
  CODE_FOR_altivec_vperm_v8hi_uns = 4520,
  CODE_FOR_altivec_vperm_v16qi_uns = 4521,
  CODE_FOR_altivec_vperm_v4sf_uns = 4522,
  CODE_FOR_altivec_vperm_v2df_uns = 4523,
  CODE_FOR_altivec_vperm_v2di_uns = 4524,
  CODE_FOR_altivec_vperm_v1ti_uns = 4525,
  CODE_FOR_altivec_vperm_ti_uns = 4526,
  CODE_FOR_altivec_vperm_kf_uns = 4527,
  CODE_FOR_altivec_vperm_tf_uns = 4528,
  CODE_FOR_vec_permv16qi = 4529,
  CODE_FOR_altivec_copysign_v4sf3 = 4530,
  CODE_FOR_cbranchv16qi4 = 4531,
  CODE_FOR_altivec_vcmpne_v16qi = 4532,
  CODE_FOR_altivec_vcmpne_v8hi = 4533,
  CODE_FOR_altivec_vcmpne_v4si = 4534,
  CODE_FOR_altivec_lvsl = 4535,
  CODE_FOR_altivec_lvsr = 4536,
  CODE_FOR_build_vector_mask_for_load = 4537,
  CODE_FOR_altivec_lvx_v4si = 4538,
  CODE_FOR_altivec_lvx_v8hi = 4539,
  CODE_FOR_altivec_lvx_v16qi = 4540,
  CODE_FOR_altivec_lvx_v4sf = 4541,
  CODE_FOR_altivec_lvx_v2df = 4542,
  CODE_FOR_altivec_lvx_v2di = 4543,
  CODE_FOR_altivec_lvx_v1ti = 4544,
  CODE_FOR_altivec_lvx_kf = 4545,
  CODE_FOR_altivec_lvx_tf = 4546,
  CODE_FOR_altivec_stvx_v4si = 4547,
  CODE_FOR_altivec_stvx_v8hi = 4548,
  CODE_FOR_altivec_stvx_v16qi = 4549,
  CODE_FOR_altivec_stvx_v4sf = 4550,
  CODE_FOR_altivec_stvx_v2df = 4551,
  CODE_FOR_altivec_stvx_v2di = 4552,
  CODE_FOR_altivec_stvx_v1ti = 4553,
  CODE_FOR_altivec_stvx_kf = 4554,
  CODE_FOR_altivec_stvx_tf = 4555,
  CODE_FOR_doubleev4sf2 = 4556,
  CODE_FOR_doubleev4si2 = 4557,
  CODE_FOR_unsdoubleev4si2 = 4558,
  CODE_FOR_doubleov4sf2 = 4559,
  CODE_FOR_doubleov4si2 = 4560,
  CODE_FOR_unsdoubleov4si2 = 4561,
  CODE_FOR_doublehv4sf2 = 4562,
  CODE_FOR_doublehv4si2 = 4563,
  CODE_FOR_unsdoublehv4si2 = 4564,
  CODE_FOR_doublelv4sf2 = 4565,
  CODE_FOR_doublelv4si2 = 4566,
  CODE_FOR_unsdoublelv4si2 = 4567,
  CODE_FOR_convert_4f32_8i16 = 4568,
  CODE_FOR_convert_4f32_8f16 = 4569,
  CODE_FOR_absv4si2 = 4570,
  CODE_FOR_absv8hi2 = 4571,
  CODE_FOR_absv16qi2 = 4572,
  CODE_FOR_absv2di2 = 4573,
  CODE_FOR_nabsv4si2 = 4574,
  CODE_FOR_nabsv8hi2 = 4575,
  CODE_FOR_nabsv16qi2 = 4576,
  CODE_FOR_nabsv2di2 = 4577,
  CODE_FOR_altivec_absv4sf2 = 4578,
  CODE_FOR_altivec_abss_v4si = 4579,
  CODE_FOR_altivec_abss_v8hi = 4580,
  CODE_FOR_altivec_abss_v16qi = 4581,
  CODE_FOR_reduc_plus_scal_v8hi = 4582,
  CODE_FOR_reduc_plus_scal_v16qi = 4583,
  CODE_FOR_negv4si2 = 4584,
  CODE_FOR_negv8hi2 = 4585,
  CODE_FOR_negv16qi2 = 4586,
  CODE_FOR_negv2di2 = 4587,
  CODE_FOR_udot_prodv4siv8hi = 4588,
  CODE_FOR_udot_prodv4siv16qi = 4589,
  CODE_FOR_sdot_prodv4siv8hi = 4590,
  CODE_FOR_widen_usumv8hi3 = 4591,
  CODE_FOR_widen_usumv16qi3 = 4592,
  CODE_FOR_widen_ssumv16qi3 = 4593,
  CODE_FOR_widen_ssumv8hi3 = 4594,
  CODE_FOR_vec_unpacks_hi_v4si = 4595,
  CODE_FOR_vec_unpacks_hi_v8hi = 4596,
  CODE_FOR_vec_unpacks_hi_v16qi = 4597,
  CODE_FOR_vec_unpacks_lo_v4si = 4598,
  CODE_FOR_vec_unpacks_lo_v8hi = 4599,
  CODE_FOR_vec_unpacks_lo_v16qi = 4600,
  CODE_FOR_vec_unpacku_hi_v4si = 4601,
  CODE_FOR_vec_unpacku_hi_v8hi = 4602,
  CODE_FOR_vec_unpacku_hi_v16qi = 4603,
  CODE_FOR_vec_unpacku_lo_v4si = 4604,
  CODE_FOR_vec_unpacku_lo_v8hi = 4605,
  CODE_FOR_vec_unpacku_lo_v16qi = 4606,
  CODE_FOR_vec_widen_umult_hi_v16qi = 4607,
  CODE_FOR_vec_widen_umult_lo_v16qi = 4608,
  CODE_FOR_vec_widen_smult_hi_v16qi = 4609,
  CODE_FOR_vec_widen_smult_lo_v16qi = 4610,
  CODE_FOR_vec_widen_umult_hi_v8hi = 4611,
  CODE_FOR_vec_widen_umult_lo_v8hi = 4612,
  CODE_FOR_vec_widen_smult_hi_v8hi = 4613,
  CODE_FOR_vec_widen_smult_lo_v8hi = 4614,
  CODE_FOR_vec_pack_trunc_v2di = 4615,
  CODE_FOR_vec_pack_trunc_v4si = 4616,
  CODE_FOR_vec_pack_trunc_v8hi = 4617,
  CODE_FOR_mulv16qi3 = 4618,
  CODE_FOR_altivec_vpermxor = 4619,
  CODE_FOR_altivec_negv4sf2 = 4620,
  CODE_FOR_altivec_vrevev16qi2 = 4621,
  CODE_FOR_altivec_vrevev8hi2 = 4622,
  CODE_FOR_altivec_vrevev4si2 = 4623,
  CODE_FOR_altivec_vrevev4sf2 = 4624,
  CODE_FOR_altivec_vrevev2di2 = 4625,
  CODE_FOR_altivec_vrevev2df2 = 4626,
  CODE_FOR_vec_unpacks_float_hi_v8hi = 4627,
  CODE_FOR_vec_unpacks_float_lo_v8hi = 4628,
  CODE_FOR_vec_unpacku_float_hi_v8hi = 4629,
  CODE_FOR_vec_unpacku_float_lo_v8hi = 4630,
  CODE_FOR_usadv16qi = 4631,
  CODE_FOR_usadv8hi = 4632,
  CODE_FOR_bcdadd_eq_v1ti = 4633,
  CODE_FOR_bcdsub_eq_v1ti = 4634,
  CODE_FOR_bcdadd_lt_v1ti = 4635,
  CODE_FOR_bcdsub_lt_v1ti = 4636,
  CODE_FOR_bcdadd_le_v1ti = 4637,
  CODE_FOR_bcdsub_le_v1ti = 4638,
  CODE_FOR_bcdadd_gt_v1ti = 4639,
  CODE_FOR_bcdsub_gt_v1ti = 4640,
  CODE_FOR_bcdadd_ge_v1ti = 4641,
  CODE_FOR_bcdsub_ge_v1ti = 4642,
  CODE_FOR_bcdadd_unordered_v1ti = 4643,
  CODE_FOR_bcdsub_unordered_v1ti = 4644,
  CODE_FOR_bcdadd_eq_v16qi = 4645,
  CODE_FOR_bcdsub_eq_v16qi = 4646,
  CODE_FOR_bcdadd_lt_v16qi = 4647,
  CODE_FOR_bcdsub_lt_v16qi = 4648,
  CODE_FOR_bcdadd_le_v16qi = 4649,
  CODE_FOR_bcdsub_le_v16qi = 4650,
  CODE_FOR_bcdadd_gt_v16qi = 4651,
  CODE_FOR_bcdsub_gt_v16qi = 4652,
  CODE_FOR_bcdadd_ge_v16qi = 4653,
  CODE_FOR_bcdsub_ge_v16qi = 4654,
  CODE_FOR_bcdadd_unordered_v16qi = 4655,
  CODE_FOR_bcdsub_unordered_v16qi = 4656,
  CODE_FOR_bcdinvalid_v1ti = 4657,
  CODE_FOR_bcdinvalid_v16qi = 4658,
  CODE_FOR_bcdmul10_v16qi = 4659,
  CODE_FOR_bcddiv10_v16qi = 4660,
  CODE_FOR_movoo = 4661,
  CODE_FOR_movxo = 4662,
  CODE_FOR_vsx_assemble_pair = 4663,
  CODE_FOR_vsx_disassemble_pair = 4664,
  CODE_FOR_mma_assemble_acc = 4665,
  CODE_FOR_mma_disassemble_acc = 4666,
  CODE_FOR_extendsdtd2 = 4667,
  CODE_FOR_dfp_denbcd_v16qi = 4668,
  CODE_FOR_dfptstsfi_eq_dd = 4669,
  CODE_FOR_dfptstsfi_lt_dd = 4670,
  CODE_FOR_dfptstsfi_gt_dd = 4671,
  CODE_FOR_dfptstsfi_unordered_dd = 4672,
  CODE_FOR_dfptstsfi_eq_td = 4673,
  CODE_FOR_dfptstsfi_lt_td = 4674,
  CODE_FOR_dfptstsfi_gt_td = 4675,
  CODE_FOR_dfptstsfi_unordered_td = 4676,
  CODE_FOR_tabort = 4677,
  CODE_FOR_tabortwc = 4678,
  CODE_FOR_tabortdc = 4679,
  CODE_FOR_tabortwci = 4680,
  CODE_FOR_tabortdci = 4681,
  CODE_FOR_tbegin = 4682,
  CODE_FOR_tcheck = 4683,
  CODE_FOR_tend = 4684,
  CODE_FOR_trechkpt = 4685,
  CODE_FOR_treclaim = 4686,
  CODE_FOR_tsr = 4687,
  CODE_FOR_ttest = 4688
};

const unsigned int NUM_INSN_CODES = 4689;
#endif /* GCC_INSN_CODES_H */
